@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021 Arm Limited.
+ * Copyright (c) 2016-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLBITWISEOR_H
-#define ARM_COMPUTE_CLBITWISEOR_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLBITWISEOR_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLBITWISEOR_H
 
 #include "arm_compute/runtime/CL/ICLSimpleFunction.h"
 
@@ -31,7 +31,7 @@ namespace arm_compute
 class CLCompileContext;
 class ICLTensor;
 
-/** Basic function to perform bitwise OR by running @ref CLBitwiseKernel.
+/** Basic function to perform bitwise OR by running CLBitwiseKernel.
  *
  * @note The tensor data type for the inputs must be U8.
  * @note The function performs a bitwise OR operation using the two input tensors.
@@ -61,7 +61,10 @@ public:
      * @param[in]  input2          Input tensor. Data types supported: U8.
      * @param[out] output          Output tensor. Data types supported: U8.
      */
-    void configure(const CLCompileContext &compile_context, const ICLTensor *input1, const ICLTensor *input2, ICLTensor *output);
+    void configure(const CLCompileContext &compile_context,
+                   const ICLTensor        *input1,
+                   const ICLTensor        *input2,
+                   ICLTensor              *output);
 };
-}
-#endif /* ARM_COMPUTE_CLBITWISEOR_H */
+} // namespace arm_compute
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLBITWISEOR_H
