@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Arm Limited.
+ * Copyright (c) 2018-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLCOMPARISON_H
-#define ARM_COMPUTE_CLCOMPARISON_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLCOMPARISON_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLCOMPARISON_H
 
 #include "arm_compute/core/Types.h"
 #include "arm_compute/runtime/CL/ICLSimpleFunction.h"
@@ -34,7 +34,7 @@ class CLCompileContext;
 class ICLTensor;
 class ITensorInfo;
 
-/** Basic function to run @ref CLComparisonKernel */
+/** Basic function to run CLComparisonKernel */
 class CLComparison : public ICLSimpleFunction
 {
 public:
@@ -66,7 +66,11 @@ public:
      * @param[out] output          Destination tensor. Data types supported: U8.
      * @param[out] operation       Comparison operation to be used.
      */
-    void configure(const CLCompileContext &compile_context, ICLTensor *input1, ICLTensor *input2, ICLTensor *output, ComparisonOperation operation);
+    void configure(const CLCompileContext &compile_context,
+                   ICLTensor              *input1,
+                   ICLTensor              *input2,
+                   ICLTensor              *output,
+                   ComparisonOperation     operation);
     /** Static function to check if given info will lead to a valid configuration of @ref CLComparison
      *
      * @param[in]  input1    Source tensor. Data types supported: All.
@@ -76,10 +80,13 @@ public:
      *
      * @return a status
      */
-    static Status validate(const ITensorInfo *input1, const ITensorInfo *input2, const ITensorInfo *output, ComparisonOperation operation);
+    static Status validate(const ITensorInfo  *input1,
+                           const ITensorInfo  *input2,
+                           const ITensorInfo  *output,
+                           ComparisonOperation operation);
 };
 
-/** Basic function to run @ref CLComparisonKernel */
+/** Basic function to run CLComparisonKernel */
 template <ComparisonOperation COP>
 class CLComparisonStatic : public ICLSimpleFunction
 {
@@ -133,4 +140,4 @@ using CLLess = CLComparisonStatic<ComparisonOperation::Less>;
 /** Basic function to run less-equal comparison. */
 using CLLessEqual = CLComparisonStatic<ComparisonOperation::LessEqual>;
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_CLCOMPARISON_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLCOMPARISON_H
