@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2021 Arm Limited.
+ * Copyright (c) 2017-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLDECONVOLUTIONLAYERUPSAMPLE_H
-#define ARM_COMPUTE_CLDECONVOLUTIONLAYERUPSAMPLE_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLDECONVOLUTIONLAYERUPSAMPLE_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLDECONVOLUTIONLAYERUPSAMPLE_H
 
 #include "arm_compute/core/Types.h"
 #include "arm_compute/runtime/CL/functions/CLFill.h"
@@ -41,7 +41,7 @@ class ITensorInfo;
 /** Basic function to execute deconvolution upsample on OpenCL. This function calls the following OpenCL kernels and functions:
  *
  * -# @ref CLFill
- * -# @ref CLDeconvolutionLayerUpsampleKernel
+ * -# CLDeconvolutionLayerUpsampleKernel
  */
 class CLDeconvolutionLayerUpsample : public IFunction
 {
@@ -82,7 +82,8 @@ public:
      * @param[out]     output          Destination tensor. Data type supported: same as @p input.
      * @param[in]      info            Contains padding and policies to be used in the deconvolution.
      */
-    void configure(const CLCompileContext &compile_context, ICLTensor *input, ICLTensor *output, const PadStrideInfo &info);
+    void
+    configure(const CLCompileContext &compile_context, ICLTensor *input, ICLTensor *output, const PadStrideInfo &info);
     /** Static function to check if given info will lead to a valid configuration of @ref CLDeconvolutionLayerUpsample
      *
      * @param[in] input  Source tensor info. Data type supported: All.
@@ -102,4 +103,4 @@ private:
     ICLTensor                                          *_output;
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_CLDECONVOLUTIONLAYERUPSAMPLE_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLDECONVOLUTIONLAYERUPSAMPLE_H
