@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2020 Arm Limited.
+ * Copyright (c) 2018-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,22 +21,31 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLTILE_H
-#define ARM_COMPUTE_CLTILE_H
-
-#include "arm_compute/runtime/CL/ICLSimpleFunction.h"
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
 
 #include "arm_compute/core/Types.h"
+#include "arm_compute/runtime/CL/ICLSimpleFunction.h"
 
 namespace arm_compute
 {
+class CLCompileContext;
 class ICLTensor;
+class ITensorInfo;
 
-/** Basic function to run @ref CLTileKernel */
+/** Basic function to run CLTileKernel */
 class CLTile : public ICLSimpleFunction
 {
 public:
     /** Set the source, destination of the kernel
+     *
+     * Valid data layouts:
+     * - All
+     *
+     * Valid data type configurations:
+     * |src            |dst            |
+     * |:--------------|:--------------|
+     * |All            |All            |
      *
      * @param[in]  input     Source tensor. Data type supported: All.
      * @param[in]  multiples Contains the number of times the input tensor should be replicated on the given dimension.
@@ -50,7 +59,10 @@ public:
      * @param[in]  multiples       Contains the number of times the input tensor should be replicated on the given dimension.
      * @param[out] output          Destination tensor. Same as @p input
      */
-    void configure(const CLCompileContext &compile_context, const ICLTensor *input, ICLTensor *output, const Multiples &multiples);
+    void configure(const CLCompileContext &compile_context,
+                   const ICLTensor        *input,
+                   ICLTensor              *output,
+                   const Multiples        &multiples);
     /** Static function to check if given info will lead to a valid configuration of @ref CLTile
      *
      * @param[in] input     Source tensor info. Data type supported: All.
@@ -62,4 +74,4 @@ public:
     static Status validate(const ITensorInfo *input, const ITensorInfo *output, const Multiples &multiples);
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_CLTILE_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
