@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2021 Arm Limited.
+ * Copyright (c) 2017-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLTRANSPOSE_H
-#define ARM_COMPUTE_CLTRANSPOSE_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTRANSPOSE_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTRANSPOSE_H
 
 #include "arm_compute/core/Error.h"
 #include "arm_compute/runtime/IFunction.h"
@@ -35,7 +35,7 @@ class CLCompileContext;
 class ICLTensor;
 class ITensorInfo;
 
-/** Basic function to execute an @ref opencl::kernels::ClTransposeKernel. */
+/** Basic function to execute an opencl::kernels::ClTransposeKernel. */
 class CLTranspose : public IFunction
 {
 public:
@@ -88,6 +88,6 @@ private:
     struct Impl;
     std::unique_ptr<Impl> _impl;
 };
-}
+} // namespace arm_compute
 
-#endif /* ARM_COMPUTE_CLTRANSPOSE_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTRANSPOSE_H
