@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Arm Limited.
+ * Copyright (c) 2018-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_NECHANNELSHUFFLELAYER_H
-#define ARM_COMPUTE_NECHANNELSHUFFLELAYER_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NECHANNELSHUFFLELAYER_H
+#define ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NECHANNELSHUFFLELAYER_H
 
 #include "arm_compute/core/Types.h"
 #include "arm_compute/runtime/NEON/INESimpleFunctionNoBorder.h"
@@ -33,7 +33,7 @@ namespace arm_compute
 class ITensor;
 class ITensorInfo;
 
-/** Basic function to run @ref NEChannelShuffleLayerKernel
+/** Basic function to run NEChannelShuffleLayerKernel
  *
  * @note The function performs a channel shuffle operation on the input tensor. Given NCHW tensor with group G, it will
  * first divide the channels into G groups, C = (G * C'), and perform a transpose of the channel, which gives C = (C' * G).
@@ -69,4 +69,4 @@ public:
     static Status validate(const ITensorInfo *input, const ITensorInfo *output, unsigned int num_groups);
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_NECHANNELSHUFFLELAYER_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NECHANNELSHUFFLELAYER_H
