@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2021 Arm Limited.
+ * Copyright (c) 2017-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,12 +21,13 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_NEL2NORMALIZELAYER_H
-#define ARM_COMPUTE_NEL2NORMALIZELAYER_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NEL2NORMALIZELAYER_H
+#define ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NEL2NORMALIZELAYER_H
 
 #include "arm_compute/runtime/IFunction.h"
 #include "arm_compute/runtime/IMemoryManager.h"
 #include "arm_compute/runtime/MemoryGroup.h"
+#include "arm_compute/runtime/MemoryManagerOnDemand.h"
 #include "arm_compute/runtime/NEON/functions/NEReductionOperation.h"
 #include "arm_compute/runtime/Tensor.h"
 
@@ -41,13 +42,16 @@ class NEL2NormalizeLayerKernel;
  *
  * This function runs the following kernels:
  * -# @ref NEReductionOperation
- * -# @ref NEL2NormalizeLayerKernel
+ * -# NEL2NormalizeLayerKernel
  */
 class NEL2NormalizeLayer : public IFunction
 {
 public:
     /** Constructor */
-    NEL2NormalizeLayer(std::shared_ptr<IMemoryManager> memory_manager = nullptr);
+    NEL2NormalizeLayer(std::shared_ptr<IMemoryManager> memory_manager);
+    NEL2NormalizeLayer() : NEL2NormalizeLayer(MemoryManagerOnDemand::make_default())
+    {
+    }
     /** Prevent instances of this class from being copied (As this class contains pointers) */
     NEL2NormalizeLayer(const NEL2NormalizeLayer &) = delete;
     /** Prevent instances of this class from being copied (As this class contains pointers) */
@@ -97,5 +101,5 @@ private:
     std::unique_ptr<NEL2NormalizeLayerKernel> _normalize_kernel;
     Tensor                                    _sumsq;
 };
-}
-#endif /* ARM_COMPUTE_NEL2NORMALIZELAYER_H */
+} // namespace arm_compute
+#endif // ACL_ARM_COMPUTE_RUNTIME_NEON_FUNCTIONS_NEL2NORMALIZELAYER_H
