@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, 2023 Arm Limited.
+ * Copyright (c) 2021, 2023-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -87,144 +87,144 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
   );
 
   __asm__ __volatile__(
-    "mov x23, #0x0\n"
-    "mov x22, #0x0\n"
+    "mov x10, #0x0\n"
+    "mov x9, #0x0\n"
     "1:"  // Tile loop
-    "str x23, [%x[params_struct], %[offsetof_args_tile_i]]\n"
+    "str x10, [%x[params_struct], %[offsetof_args_tile_i]]\n"
+    "mov x28, #0x2\n"
     "mov x27, #0x2\n"
-    "mov x26, #0x2\n"
-    "str x22, [%x[params_struct], %[offsetof_args_tile_j]]\n"
-    "ldr x25, [%x[params_struct], %[offsetof_args_ld_input_row]]\n"
-    "ldr x24, [%x[params_struct], %[offsetof_args_ld_output_row]]\n"
-    "mul x21, x23, x25\n"  // offset = tile_i * ld_input_row
+    "str x9, [%x[params_struct], %[offsetof_args_tile_j]]\n"
+    "ldr x26, [%x[params_struct], %[offsetof_args_ld_input_row]]\n"
+    "ldr x25, [%x[params_struct], %[offsetof_args_ld_output_row]]\n"
+    "mov x16, #0x10\n"  // cntb _, ALL, #1
     "ldr x15, [%x[params_struct], %[offsetof_args_ld_input_col]]\n"
     "ldr x14, [%x[params_struct], %[offsetof_args_ld_output_col]]\n"
-    "mul x20, x23, x24\n"  // offset = tile_i * ld_output_row
-    "mov x23, #0x10\n"  // cntb _, ALL, #1
-    "madd x21, x22, x15, x21\n"  // offset += tile_j * ld_input_col
-    "ldr x13, [%x[params_struct], %[offsetof_args_inptr]]\n"
-    "lsl x15, x15, #0x1\n"
-    "ldr x12, [%x[params_struct], %[offsetof_args_outptr]]\n"
-    "madd x20, x22, x14, x20\n"  // offset += tile_j * ld_output_col
-    "lsr x22, %x[n_channels], #0x3\n"
-    "add x11, x15, x15\n"
-    "ldr x10, [%x[params_struct], %[offsetof_args_params]]\n"
-    "mul x21, x21, x27\n"  // offset *= kernel_stride * output_size
-    "add x13, x13, x21, LSL #1\n"  // inptr[0] += offset * sizeof(__fp16)
-    "add x9, x13, x25, LSL #1\n"
-    "mul x20, x20, x26\n"  // offset *= output_tile_size
-    "add x28, x9, x25, LSL #1\n"
-    "add x12, x12, x20, LSL #1\n"  // outptrs[0] += offset * sizeof(__fp16)
+    "lsr x24, %x[n_channels], #0x3\n"
     "add x20, %x[params_struct], %[offsetof_args_min]\n"
     "ld1r { v27.8h }, [x20]\n"
+    "ldr x13, [%x[params_struct], %[offsetof_args_inptr]]\n"
     "add x20, %x[params_struct], %[offsetof_args_max]\n"
+    "mov x23, #0x0\n"
     "ld1r { v26.8h }, [x20]\n"
-    "add x27, x28, x25, LSL #1\n"
-    "add x26, x11, x15\n"
-    "add x25, x12, x24, LSL #1\n"
+    "mul x22, x10, x26\n"  // offset = tile_i * ld_input_row
+    "ldr x12, [%x[params_struct], %[offsetof_args_outptr]]\n"
+    "sub x21, XZR, x16\n"
+    "mul x20, x10, x25\n"  // offset = tile_i * ld_output_row
+    "ldr x11, [%x[params_struct], %[offsetof_args_params]]\n"
+    "madd x22, x9, x15, x22\n"  // offset += tile_j * ld_input_col
+    "lsl x15, x15, #0x1\n"
+    "madd x20, x9, x14, x20\n"  // offset += tile_j * ld_output_col
     "lsl x14, x14, #0x1\n"
-    "mov x21, #0x0\n"
-    "sub x20, XZR, x23\n"
-    "cbz x22, 4f\n"
-    "ldr q25, [x10, #0x0]\n"
-    "ldr q0, [x10, #0x10]\n"
-    "cmp x23, x22, LSL #4\n"
-    "ldr q1, [x10, #0x20]\n"
-    "ldr q2, [x10, #0x30]\n"
-    "ldr q3, [x10, #0x40]\n"
-    "ldr q4, [x10, #0x50]\n"
-    "ldr q5, [x10, #0x60]\n"
-    "ldr q6, [x10, #0x70]\n"
-    "ldr q7, [x10, #0x80]\n"
-    "ldr q8, [x10, #0x90]\n"
-    "add x10, x10, #0xa0\n"
-    "ldr q9, [x9, x15]\n"
+    "mul x22, x22, x28\n"  // offset *= kernel_stride * output_size
+    "add x10, x15, x15\n"
+    "add x9, x10, x15\n"
+    "mul x20, x20, x27\n"  // offset *= output_tile_size
+    "add x13, x13, x22, LSL #1\n"  // inptr[0] += offset * sizeof(__fp16)
+    "add x28, x13, x26, LSL #1\n"
+    "add x27, x28, x26, LSL #1\n"
+    "add x26, x27, x26, LSL #1\n"
+    "add x12, x12, x20, LSL #1\n"  // outptrs[0] += offset * sizeof(__fp16)
+    "add x25, x12, x25, LSL #1\n"
+    "cbz x24, 4f\n"
+    "ldr q25, [x11, #0x0]\n"
+    "ldr q0, [x11, #0x10]\n"
+    "cmp x16, x24, LSL #4\n"
+    "ldr q1, [x11, #0x20]\n"
+    "ldr q2, [x11, #0x30]\n"
+    "ldr q3, [x11, #0x40]\n"
+    "ldr q4, [x11, #0x50]\n"
+    "ldr q5, [x11, #0x60]\n"
+    "ldr q6, [x11, #0x70]\n"
+    "ldr q7, [x11, #0x80]\n"
+    "ldr q8, [x11, #0x90]\n"
+    "add x11, x11, #0xa0\n"
+    "ldr q9, [x28, x15]\n"
     "ld1 { v10.8h }, [x13]\n"
-    "ldr q11, [x13, x26]\n"
-    "ldr q12, [x9, x11]\n"
-    "ldr q13, [x28, x15]\n"
+    "ldr q11, [x13, x9]\n"
+    "ldr q12, [x28, x10]\n"
+    "ldr q13, [x27, x15]\n"
     "bge 3f\n"
     "2:"  // Tile loop: Channel loop
     "mov v24.16b, v25.16b\n fmla v24.8h, v4.8h, v9.8h\n"
     "mov v23.16b, v25.16b\n fmla v23.8h, v3.8h, v9.8h\n"
-    "add x23, x23, #0x10\n"
-    "cmp x23, x22, LSL #4\n"
+    "add x16, x16, #0x10\n"
+    "add x21, x21, #0x10\n"
     "mov v22.16b, v25.16b\n fmla v22.8h, v1.8h, v9.8h\n"
     "mov v21.16b, v25.16b\n fmla v21.8h, v0.8h, v9.8h\n"
-    "ld1 { v18.8h }, [x27]\n"
-    "ldr q25, [x10, #0x0]\n"
+    "ld1 { v18.8h }, [x26]\n"
+    "ldr q25, [x11, #0x0]\n"
+    "cmp x16, x24, LSL #4\n"
+    "add x23, x23, #0x10\n"
     "fmla v24.8h, v0.8h, v10.8h\n"
-    "ldr q20, [x28, x11]\n"
+    "ldr q20, [x27, x10]\n"
     "fmla v23.8h, v2.8h, v11.8h\n"
-    "ldr q17, [x27, x26]\n"
+    "ldr q17, [x26, x9]\n"
     "fmla v22.8h, v2.8h, v12.8h\n"
     "fmla v21.8h, v1.8h, v12.8h\n"
-    "add x20, x20, #0x10\n"
-    "add x21, x21, #0x10\n"
     "fmla v24.8h, v5.8h, v12.8h\n"
     "fmla v23.8h, v4.8h, v12.8h\n"
     "ldr q16, [x13, x15]\n"
     "fmla v22.8h, v6.8h, v18.8h\n"
-    "ldr q18, [x13, x11]\n"
-    "fmla v21.8h, v3.8h, v13.8h\n"
+    "ldr q18, [x13, x10]\n"
     "add x13, x13, #0x10\n"
+    "fmla v21.8h, v3.8h, v13.8h\n"
     "fmla v24.8h, v7.8h, v13.8h\n"
     "fmla v23.8h, v6.8h, v13.8h\n"
     "fmla v22.8h, v4.8h, v13.8h\n"
     "fmla v21.8h, v8.8h, v17.8h\n"
-    "ld1 { v17.8h }, [x9]\n"
+    "ld1 { v17.8h }, [x28]\n"
     "fmla v24.8h, v1.8h, v16.8h\n"
     "fmla v23.8h, v0.8h, v16.8h\n"
-    "ldr q16, [x9, x26]\n"
-    "add x9, x9, #0x10\n"
+    "ldr q16, [x28, x9]\n"
+    "add x28, x28, #0x10\n"
     "fmla v22.8h, v5.8h, v20.8h\n"
     "fmla v21.8h, v4.8h, v20.8h\n"
-    "ldr q4, [x10, #0x50]\n"
+    "ldr q4, [x11, #0x50]\n"
     "fmla v24.8h, v2.8h, v18.8h\n"
     "fmla v23.8h, v1.8h, v18.8h\n"
-    "ld1 { v19.8h }, [x28]\n"
-    "ldr q1, [x10, #0x20]\n"
+    "ld1 { v19.8h }, [x27]\n"
+    "ldr q1, [x11, #0x20]\n"
     "fmla v22.8h, v0.8h, v17.8h\n"
-    "ldr q0, [x10, #0x10]\n"
+    "ldr q0, [x11, #0x10]\n"
     "fmla v21.8h, v2.8h, v16.8h\n"
-    "ldr q2, [x10, #0x30]\n"
+    "ldr q2, [x11, #0x30]\n"
     "fmla v24.8h, v8.8h, v20.8h\n"
     "fmla v23.8h, v7.8h, v20.8h\n"
-    "ldr q18, [x28, x26]\n"
-    "add x28, x28, #0x10\n"
-    "ldr q13, [x28, x15]\n"
+    "ldr q18, [x27, x9]\n"
+    "add x27, x27, #0x10\n"
+    "ldr q13, [x27, x15]\n"
     "fmla v22.8h, v3.8h, v19.8h\n"
     "fmla v21.8h, v5.8h, v18.8h\n"
     "fmla v24.8h, v3.8h, v17.8h\n"
-    "ldr q17, [x27, x15]\n"
-    "ldr q3, [x10, #0x40]\n"
+    "ldr q17, [x26, x15]\n"
+    "ldr q3, [x11, #0x40]\n"
     "fmla v23.8h, v5.8h, v16.8h\n"
-    "ldr q16, [x27, x11]\n"
-    "ldr q5, [x10, #0x60]\n"
+    "ldr q16, [x26, x10]\n"
+    "ldr q5, [x11, #0x60]\n"
+    "add x26, x26, #0x10\n"
     "fmla v22.8h, v7.8h, v17.8h\n"
     "fmla v21.8h, v6.8h, v17.8h\n"
-    "ldr q11, [x13, x26]\n"
+    "ldr q11, [x13, x9]\n"
     "fmla v24.8h, v6.8h, v19.8h\n"
-    "ldr q9, [x9, x15]\n"
+    "ldr q9, [x28, x15]\n"
+    "ldr q6, [x11, #0x70]\n"
     "fmla v23.8h, v8.8h, v18.8h\n"
     "ld1 { v10.8h }, [x13]\n"
-    "ldr q6, [x10, #0x70]\n"
     "fmla v22.8h, v8.8h, v16.8h\n"
+    "ldr q8, [x11, #0x90]\n"
     "fmla v21.8h, v7.8h, v16.8h\n"
-    "ldr q12, [x9, x11]\n"
-    "ldr q7, [x10, #0x80]\n"
+    "ldr q12, [x28, x10]\n"
+    "ldr q7, [x11, #0x80]\n"
+    "add x11, x11, #0xa0\n"
     "fmax v24.8h, v24.8h, v27.8h\n"
     "fmax v23.8h, v23.8h, v27.8h\n"
-    "ldr q8, [x10, #0x90]\n"
     "fmax v22.8h, v22.8h, v27.8h\n"
     "fmax v21.8h, v21.8h, v27.8h\n"
-    "add x27, x27, #0x10\n"
     "fmin v24.8h, v24.8h, v26.8h\n"
     "fmin v23.8h, v23.8h, v26.8h\n"
-    "st1 { v24.8h }, [x12]\n"
-    "add x10, x10, #0xa0\n"
     "fmin v22.8h, v22.8h, v26.8h\n"
     "fmin v21.8h, v21.8h, v26.8h\n"
+    "st1 { v24.8h }, [x12]\n"
     "str q23, [x12, x14]\n"
     "add x12, x12, #0x10\n"
     "st1 { v22.8h }, [x25]\n"
@@ -236,58 +236,58 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "mov v23.16b, v25.16b\n fmla v23.8h, v3.8h, v9.8h\n"
     "mov v22.16b, v25.16b\n fmla v22.8h, v1.8h, v9.8h\n"
     "mov v21.16b, v25.16b\n fmla v21.8h, v0.8h, v9.8h\n"
-    "ld1 { v18.8h }, [x27]\n"
+    "ld1 { v18.8h }, [x26]\n"
     "fmla v24.8h, v0.8h, v10.8h\n"
-    "ldr q20, [x28, x11]\n"
+    "ldr q20, [x27, x10]\n"
     "fmla v23.8h, v2.8h, v11.8h\n"
-    "ldr q17, [x27, x26]\n"
+    "ldr q17, [x26, x9]\n"
     "fmla v22.8h, v2.8h, v12.8h\n"
     "fmla v21.8h, v1.8h, v12.8h\n"
     "fmla v24.8h, v5.8h, v12.8h\n"
     "fmla v23.8h, v4.8h, v12.8h\n"
     "ldr q16, [x13, x15]\n"
     "fmla v22.8h, v6.8h, v18.8h\n"
-    "ldr q18, [x13, x11]\n"
-    "fmla v21.8h, v3.8h, v13.8h\n"
+    "ldr q18, [x13, x10]\n"
     "add x13, x13, #0x10\n"
+    "fmla v21.8h, v3.8h, v13.8h\n"
     "fmla v24.8h, v7.8h, v13.8h\n"
     "fmla v23.8h, v6.8h, v13.8h\n"
     "fmla v22.8h, v4.8h, v13.8h\n"
     "fmla v21.8h, v8.8h, v17.8h\n"
-    "ld1 { v17.8h }, [x9]\n"
+    "ld1 { v17.8h }, [x28]\n"
     "fmla v24.8h, v1.8h, v16.8h\n"
     "fmla v23.8h, v0.8h, v16.8h\n"
-    "ldr q16, [x9, x26]\n"
-    "add x9, x9, #0x10\n"
+    "ldr q16, [x28, x9]\n"
+    "add x28, x28, #0x10\n"
     "fmla v22.8h, v5.8h, v20.8h\n"
     "fmla v21.8h, v4.8h, v20.8h\n"
     "fmla v24.8h, v2.8h, v18.8h\n"
     "fmla v23.8h, v1.8h, v18.8h\n"
-    "ld1 { v19.8h }, [x28]\n"
+    "ld1 { v19.8h }, [x27]\n"
     "fmla v22.8h, v0.8h, v17.8h\n"
     "fmla v21.8h, v2.8h, v16.8h\n"
     "fmla v24.8h, v8.8h, v20.8h\n"
     "fmla v23.8h, v7.8h, v20.8h\n"
-    "ldr q18, [x28, x26]\n"
-    "add x28, x28, #0x10\n"
+    "ldr q18, [x27, x9]\n"
+    "add x27, x27, #0x10\n"
     "fmla v22.8h, v3.8h, v19.8h\n"
     "fmla v21.8h, v5.8h, v18.8h\n"
     "fmla v24.8h, v3.8h, v17.8h\n"
-    "ldr q17, [x27, x15]\n"
+    "ldr q17, [x26, x15]\n"
     "fmla v23.8h, v5.8h, v16.8h\n"
-    "ldr q16, [x27, x11]\n"
+    "ldr q16, [x26, x10]\n"
+    "add x26, x26, #0x10\n"
     "fmla v22.8h, v7.8h, v17.8h\n"
     "fmla v21.8h, v6.8h, v17.8h\n"
-    "add x27, x27, #0x10\n"
     "fmla v24.8h, v6.8h, v19.8h\n"
     "fmla v23.8h, v8.8h, v18.8h\n"
-    "fmax v24.8h, v24.8h, v27.8h\n"
     "fmla v22.8h, v8.8h, v16.8h\n"
     "fmla v21.8h, v7.8h, v16.8h\n"
+    "fmax v24.8h, v24.8h, v27.8h\n"
     "fmax v23.8h, v23.8h, v27.8h\n"
+    "fmin v24.8h, v24.8h, v26.8h\n"
     "fmax v22.8h, v22.8h, v27.8h\n"
     "fmax v21.8h, v21.8h, v27.8h\n"
-    "fmin v24.8h, v24.8h, v26.8h\n"
     "fmin v23.8h, v23.8h, v26.8h\n"
     "st1 { v24.8h }, [x12]\n"
     "fmin v22.8h, v22.8h, v26.8h\n"
@@ -300,21 +300,21 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "4:"  // Tile loop: Oddments
     "tst %x[n_channels], #0x7\n"
     "beq 57f\n"
-    "ldr q25, [x10, #0x0]\n"
-    "ldr q0, [x10, #0x10]\n"
-    "add x24, x9, x15\n"
+    "ldr q25, [x11, #0x0]\n"
+    "ldr q0, [x11, #0x10]\n"
+    "add x24, x28, x15\n"
     "add x23, x13, XZR\n"
-    "ldr q1, [x10, #0x20]\n"
-    "ldr q2, [x10, #0x30]\n"
-    "add x22, x13, x26\n"
-    "add x21, x9, x11\n"
-    "ldr q3, [x10, #0x40]\n"
-    "ldr q4, [x10, #0x50]\n"
-    "add x20, x28, x15\n"
-    "ldr q5, [x10, #0x60]\n"
-    "ldr q6, [x10, #0x70]\n"
-    "ldr q7, [x10, #0x80]\n"
-    "ldr q8, [x10, #0x90]\n"
+    "ldr q1, [x11, #0x20]\n"
+    "ldr q2, [x11, #0x30]\n"
+    "add x22, x13, x9\n"
+    "add x21, x28, x10\n"
+    "ldr q3, [x11, #0x40]\n"
+    "ldr q4, [x11, #0x50]\n"
+    "add x20, x27, x15\n"
+    "ldr q5, [x11, #0x60]\n"
+    "ldr q6, [x11, #0x70]\n"
+    "ldr q7, [x11, #0x80]\n"
+    "ldr q8, [x11, #0x90]\n"
     "tbz %x[n_channels], #2, 6f\n"
     "ldr d9, [x24], #0x8\n"
     "ldr d10, [x23], #0x8\n"
@@ -365,15 +365,15 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "8:"  // Tile loop: Oddments: Load inputs: (1, 1), (0, 0), (0, 3), (1, 2), (2, 1): Bit 2: End
     "mov v28.16b, v25.16b\n fmla v28.8h, v4.8h, v9.8h\n"
     "mov v29.16b, v25.16b\n fmla v29.8h, v3.8h, v9.8h\n"
-    "add x20, x27, XZR\n"
+    "add x20, x26, XZR\n"
     "mov v30.16b, v25.16b\n fmla v30.8h, v1.8h, v9.8h\n"
     "mov v31.16b, v25.16b\n fmla v31.8h, v0.8h, v9.8h\n"
     "fmla v28.8h, v0.8h, v10.8h\n"
     "fmla v29.8h, v2.8h, v11.8h\n"
-    "fmla v28.8h, v5.8h, v12.8h\n"
-    "fmla v29.8h, v4.8h, v12.8h\n"
     "fmla v30.8h, v2.8h, v12.8h\n"
     "fmla v31.8h, v1.8h, v12.8h\n"
+    "fmla v28.8h, v5.8h, v12.8h\n"
+    "fmla v29.8h, v4.8h, v12.8h\n"
     "tbz %x[n_channels], #2, 10f\n"
     "ldr d9, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 9f\n"
@@ -396,10 +396,10 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "12:"  // Tile loop: Oddments: Load inputs: (3, 0): Bit 2: End
     "fmla v30.8h, v6.8h, v9.8h\n"
     "fmla v28.8h, v7.8h, v13.8h\n"
-    "add x20, x27, x26\n"
+    "add x20, x26, x9\n"
     "fmla v29.8h, v6.8h, v13.8h\n"
-    "fmla v30.8h, v4.8h, v13.8h\n"
     "fmla v31.8h, v3.8h, v13.8h\n"
+    "fmla v30.8h, v4.8h, v13.8h\n"
     "tbz %x[n_channels], #2, 14f\n"
     "ldr d11, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 13f\n"
@@ -444,7 +444,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "20:"  // Tile loop: Oddments: Load inputs: (0, 1): Bit 2: End
     "fmla v28.8h, v1.8h, v12.8h\n"
     "fmla v29.8h, v0.8h, v12.8h\n"
-    "add x20, x13, x11\n"
+    "add x20, x13, x10\n"
     "tbz %x[n_channels], #2, 22f\n"
     "ldr d9, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 21f\n"
@@ -467,7 +467,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "24:"  // Tile loop: Oddments: Load inputs: (0, 2): Bit 2: End
     "fmla v28.8h, v2.8h, v9.8h\n"
     "fmla v29.8h, v1.8h, v9.8h\n"
-    "add x20, x28, x11\n"
+    "add x20, x27, x10\n"
     "tbz %x[n_channels], #2, 26f\n"
     "ldr d10, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 25f\n"
@@ -490,7 +490,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "28:"  // Tile loop: Oddments: Load inputs: (2, 2): Bit 2: End
     "fmla v28.8h, v8.8h, v10.8h\n"
     "fmla v29.8h, v7.8h, v10.8h\n"
-    "add x20, x9, XZR\n"
+    "add x20, x28, XZR\n"
     "fmla v30.8h, v5.8h, v10.8h\n"
     "fmla v31.8h, v4.8h, v10.8h\n"
     "tbz %x[n_channels], #2, 30f\n"
@@ -515,7 +515,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "32:"  // Tile loop: Oddments: Load inputs: (1, 0): Bit 2: End
     "fmla v28.8h, v3.8h, v11.8h\n"
     "fmla v30.8h, v0.8h, v11.8h\n"
-    "add x20, x9, x26\n"
+    "add x20, x28, x9\n"
     "tbz %x[n_channels], #2, 34f\n"
     "ldr d12, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 33f\n"
@@ -538,7 +538,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "36:"  // Tile loop: Oddments: Load inputs: (1, 3): Bit 2: End
     "fmla v29.8h, v5.8h, v12.8h\n"
     "fmla v31.8h, v2.8h, v12.8h\n"
-    "add x20, x28, XZR\n"
+    "add x20, x27, XZR\n"
     "tbz %x[n_channels], #2, 38f\n"
     "ldr d9, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 37f\n"
@@ -561,7 +561,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "40:"  // Tile loop: Oddments: Load inputs: (2, 0): Bit 2: End
     "fmla v28.8h, v6.8h, v9.8h\n"
     "fmla v30.8h, v3.8h, v9.8h\n"
-    "add x20, x28, x26\n"
+    "add x20, x27, x9\n"
     "tbz %x[n_channels], #2, 42f\n"
     "ldr d10, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 41f\n"
@@ -584,7 +584,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "44:"  // Tile loop: Oddments: Load inputs: (2, 3): Bit 2: End
     "fmla v29.8h, v8.8h, v10.8h\n"
     "fmla v31.8h, v5.8h, v10.8h\n"
-    "add x20, x27, x15\n"
+    "add x20, x26, x15\n"
     "tbz %x[n_channels], #2, 46f\n"
     "ldr d11, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 45f\n"
@@ -607,7 +607,7 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "48:"  // Tile loop: Oddments: Load inputs: (3, 1): Bit 2: End
     "fmla v30.8h, v7.8h, v11.8h\n"
     "fmla v31.8h, v6.8h, v11.8h\n"
-    "add x20, x27, x11\n"
+    "add x20, x26, x10\n"
     "tbz %x[n_channels], #2, 50f\n"
     "ldr d12, [x20], #0x8\n"
     "tbz %x[n_channels], #1, 49f\n"
@@ -632,28 +632,28 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "fmla v31.8h, v7.8h, v12.8h\n"
     "fmax v28.8h, v28.8h, v27.8h\n"
     "fmax v29.8h, v29.8h, v27.8h\n"
+    "fmin v28.8h, v28.8h, v26.8h\n"
     "fmax v30.8h, v30.8h, v27.8h\n"
     "fmax v31.8h, v31.8h, v27.8h\n"
-    "fmin v28.8h, v28.8h, v26.8h\n"
     "fmin v29.8h, v29.8h, v26.8h\n"
     "fmin v30.8h, v30.8h, v26.8h\n"
     "fmin v31.8h, v31.8h, v26.8h\n"
     "tbz %x[n_channels], #2, 54f\n"
     "mov x21, x12\n"
     "mov x20, x25\n"
-    "st1 { v28.d }[0], [x21], x14\n"
-    "st1 { v30.d }[0], [x20], x14\n"
     "add x12, x12, #0x8\n"
     "add x25, x25, #0x8\n"
+    "st1 { v28.d }[0], [x21], x14\n"
+    "st1 { v30.d }[0], [x20], x14\n"
     "st1 { v29.d }[0], [x21]\n"
     "st1 { v31.d }[0], [x20]\n"
     "tbz %x[n_channels], #1, 53f\n"
     "mov x21, x12\n"
     "mov x20, x25\n"
-    "st1 { v28.s }[2], [x21], x14\n"
-    "st1 { v30.s }[2], [x20], x14\n"
     "add x12, x12, #0x4\n"
     "add x25, x25, #0x4\n"
+    "st1 { v28.s }[2], [x21], x14\n"
+    "st1 { v30.s }[2], [x20], x14\n"
     "st1 { v29.s }[2], [x21]\n"
     "st1 { v31.s }[2], [x20]\n"
     "tbz %x[n_channels], #0, 56f\n"
@@ -677,10 +677,10 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "tbz %x[n_channels], #1, 55f\n"
     "mov x21, x12\n"
     "mov x20, x25\n"
-    "st1 { v28.s }[0], [x21], x14\n"
-    "st1 { v30.s }[0], [x20], x14\n"
     "add x12, x12, #0x4\n"
     "add x25, x25, #0x4\n"
+    "st1 { v28.s }[0], [x21], x14\n"
+    "st1 { v30.s }[0], [x20], x14\n"
     "st1 { v29.s }[0], [x21]\n"
     "st1 { v31.s }[0], [x20]\n"
     "tbz %x[n_channels], #0, 56f\n"
@@ -700,20 +700,20 @@ void a64_fp16_nhwc_3x3_s1_output2x2_mla_depthfirst_direct_impl(
     "st1 { v31.h }[0], [x20]\n"
     "56:"  // Tile loop: Oddments: Store: Bit 2: End
     "57:"  // Tile loop: End
-    "ldr x22, [%x[params_struct], %[offsetof_args_tile_j]]\n"
-    "ldr x23, [%x[params_struct], %[offsetof_args_tile_i]]\n"
-    "add x22, x22, #0x1\n"
-    "add x21, x23, #0x1\n"
-    "ldr x20, [%x[params_struct], %[offsetof_args_n_tile_cols]]\n"
-    "cmp x22, x20\n"
-    "ldr x20, [%x[params_struct], %[offsetof_args_n_tile_rows]]\n"
-    "csel x23, x23, x21, LT\n"
-    "csel x22, x22, XZR, LT\n"
-    "cmp x23, x20\n"
+    "ldr x9, [%x[params_struct], %[offsetof_args_tile_j]]\n"
+    "ldr x10, [%x[params_struct], %[offsetof_args_tile_i]]\n"
+    "ldr x22, [%x[params_struct], %[offsetof_args_n_tile_cols]]\n"
+    "ldr x21, [%x[params_struct], %[offsetof_args_n_tile_rows]]\n"
+    "add x9, x9, #0x1\n"
+    "add x20, x10, #0x1\n"
+    "cmp x9, x22\n"
+    "csel x10, x10, x20, LT\n"
+    "csel x9, x9, XZR, LT\n"
+    "cmp x10, x21\n"
     "blt 1b\n"
     :
     : [n_channels] "r" ((unsigned long) n_channels), [offsetof_args_inptr] "I" (offsetof(Args, inptr)), [offsetof_args_ld_input_col] "I" (offsetof(Args, ld_input_col)), [offsetof_args_ld_input_row] "I" (offsetof(Args, ld_input_row)), [offsetof_args_ld_output_col] "I" (offsetof(Args, ld_output_col)), [offsetof_args_ld_output_row] "I" (offsetof(Args, ld_output_row)), [offsetof_args_max] "I" (offsetof(Args, max)), [offsetof_args_min] "I" (offsetof(Args, min)), [offsetof_args_n_tile_cols] "I" (offsetof(Args, n_tile_cols)), [offsetof_args_n_tile_rows] "I" (offsetof(Args, n_tile_rows)), [offsetof_args_outptr] "I" (offsetof(Args, outptr)), [offsetof_args_params] "I" (offsetof(Args, params)), [offsetof_args_tile_i] "I" (offsetof(Args, tile_i)), [offsetof_args_tile_j] "I" (offsetof(Args, tile_j)), [params_struct] "r" (&params_struct)
-    : "cc", "memory", "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7", "v8", "v9", "v10", "v11", "v12", "v13", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v30", "v31", "x9", "x10", "x11", "x12", "x13", "x14", "x15", "x20", "x21", "x22", "x23", "x24", "x25", "x26", "x27", "x28"
+    : "cc", "memory", "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7", "v8", "v9", "v10", "v11", "v12", "v13", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v30", "v31", "x9", "x10", "x11", "x12", "x13", "x14", "x15", "x16", "x20", "x21", "x22", "x23", "x24", "x25", "x26", "x27", "x28"
   );
 }
 
