@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, 2023 Arm Limited.
+ * Copyright (c) 2021, 2023-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -87,275 +87,275 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
                      activation_min, activation_max);
 
   __asm__ __volatile__(
-    "ldr x21, [%x[params_struct], %[offsetof_args_outptrs]]\n"
-    "mov x25, #0x10\n"  // cntb _, ALL, #1
-    "lsr x24, %x[n_channels], #0x3\n"
-    "ldr x23, [%x[params_struct], %[offsetof_args_params]]\n"
-    "add x20, %x[params_struct], %[offsetof_args_min]\n"
-    "ld1r { v26.8h }, [x20]\n"
+    "ldr x22, [%x[params_struct], %[offsetof_args_outptrs]]\n"
+    "mov x8, #0x10\n"  // cntb _, ALL, #1
+    "lsr x17, %x[n_channels], #0x3\n"
+    "ldr x16, [%x[params_struct], %[offsetof_args_params]]\n"
+    "add x21, %x[params_struct], %[offsetof_args_min]\n"
     "add x20, %x[params_struct], %[offsetof_args_max]\n"
+    "ld1r { v26.8h }, [x21]\n"
     "ld1r { v27.8h }, [x20]\n"
-    "add x13, %x[params_struct], %[offsetof_Args_inptrs]\n"
-    "ldp x12, x11, [x21, #0x0]\n"
-    "ldp x10, x9, [x21, #0x10]\n"
-    "mov x28, #0x0\n"
-    "sub x22, XZR, x25\n"
-    "cbz x24, 3f\n"
-    "ldr q31, [x23, #0x0]\n"
-    "ldr q0, [x23, #0x10]\n"
-    "cmp x25, x24, LSL #4\n"
-    "ldr q1, [x23, #0x20]\n"
-    "ldr q2, [x23, #0x30]\n"
-    "ldr q3, [x23, #0x40]\n"
-    "ldr q4, [x23, #0x50]\n"
-    "ldr q5, [x23, #0x60]\n"
-    "ldr q6, [x23, #0x70]\n"
-    "ldr q7, [x23, #0x80]\n"
-    "ldr q8, [x23, #0x90]\n"
-    "add x23, x23, #0xa0\n"
-    "ldp x21, x20, [x13, #0x0]\n"
-    "ldr q9, [x21, x28]\n"
-    "ldr q10, [x20, x28]\n"
-    "ldp x21, x20, [x13, #0x10]\n"
-    "ldr q11, [x21, x28]\n"
-    "ldr q12, [x20, x28]\n"
-    "ldp x21, x20, [x13, #0x20]\n"
-    "ldr q13, [x21, x28]\n"
-    "ldr q14, [x20, x28]\n"
-    "ldp x21, x20, [x13, #0x30]\n"
-    "ldr q15, [x21, x28]\n"
-    "ldr q16, [x20, x28]\n"
+    "add x15, %x[params_struct], %[offsetof_Args_inptrs]\n"
+    "mov x14, #0x0\n"
+    "ldp x13, x12, [x22, #0x0]\n"
+    "ldp x11, x10, [x22, #0x10]\n"
+    "sub x9, XZR, x8\n"
+    "cbz x17, 3f\n"
+    "ldr q31, [x16, #0x0]\n"
+    "ldr q0, [x16, #0x10]\n"
+    "cmp x8, x17, LSL #4\n"
+    "ldr q1, [x16, #0x20]\n"
+    "ldr q2, [x16, #0x30]\n"
+    "ldr q3, [x16, #0x40]\n"
+    "ldr q4, [x16, #0x50]\n"
+    "ldr q5, [x16, #0x60]\n"
+    "ldr q6, [x16, #0x70]\n"
+    "ldr q7, [x16, #0x80]\n"
+    "ldr q8, [x16, #0x90]\n"
+    "add x16, x16, #0xa0\n"
+    "ldp x27, x26, [x15, #0x0]\n"
+    "ldp x25, x24, [x15, #0x10]\n"
+    "ldp x23, x22, [x15, #0x20]\n"
+    "ldp x21, x20, [x15, #0x30]\n"
+    "ldr q9, [x27, x14]\n"
+    "ldr q10, [x26, x14]\n"
+    "ldr q11, [x25, x14]\n"
+    "ldr q12, [x24, x14]\n"
+    "ldr q13, [x23, x14]\n"
+    "ldr q14, [x22, x14]\n"
+    "ldr q15, [x21, x14]\n"
+    "ldr q16, [x20, x14]\n"
     "bge 2f\n"
     "1:"  // Channel loop
-    "mov v24.16b, v31.16b\n fmla v24.8h, v8.8h, v9.8h\n"
-    "mov v23.16b, v31.16b\n fmla v23.8h, v6.8h, v9.8h\n"
-    "ldr x21, [x13, #0x40]\n"
-    "ldr x20, [x13, #0x48]\n"
-    "fmla v24.8h, v0.8h, v10.8h\n"
-    "fmla v23.8h, v1.8h, v12.8h\n"
-    "ldr q20, [x20, x28]\n"
-    "ldr x20, [x13, #0x50]\n"
-    "fmla v24.8h, v1.8h, v11.8h\n"
-    "ldr q19, [x21, x28]\n"
-    "fmla v23.8h, v2.8h, v13.8h\n"
-    "ldr q18, [x20, x28]\n"
-    "fmla v24.8h, v3.8h, v14.8h\n"
-    "fmla v23.8h, v0.8h, v16.8h\n"
-    "ldr x20, [x13, #0x58]\n"
-    "ldr q17, [x20, x28]\n"
-    "fmla v24.8h, v4.8h, v15.8h\n"
-    "fmla v23.8h, v4.8h, v19.8h\n"
-    "ldr x21, [x13, #0x78]\n"
-    "ldr x20, [x13, #0x60]\n"
-    "ldr q22, [x20, x28]\n"
-    "fmla v24.8h, v2.8h, v16.8h\n"
-    "fmla v23.8h, v5.8h, v20.8h\n"
-    "ldr x20, [x13, #0x80]\n"
-    "ldr q21, [x20, x28]\n"
-    "mov v20.16b, v31.16b\n fmla v20.8h, v2.8h, v9.8h\n"
-    "mov v19.16b, v31.16b\n fmla v19.8h, v0.8h, v9.8h\n"
-    "ldr q31, [x23, #0x0]\n"
-    "fmla v24.8h, v5.8h, v18.8h\n"
-    "fmla v23.8h, v3.8h, v18.8h\n"
-    "ldr q16, [x21, x28]\n"
-    "ldr x20, [x13, #0x68]\n"
-    "ldr q18, [x20, x28]\n"
-    "fmla v20.8h, v3.8h, v17.8h\n"
-    "fmla v19.8h, v4.8h, v16.8h\n"
-    "ldr x20, [x13, #0x88]\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v20.8h, v0.8h, v22.8h\n"
-    "ldr q0, [x23, #0x10]\n"
-    "fmla v19.8h, v1.8h, v21.8h\n"
-    "ldr x20, [x13, #0x70]\n"
-    "ldr q17, [x20, x28]\n"
-    "fmla v20.8h, v4.8h, v18.8h\n"
-    "fmla v19.8h, v5.8h, v16.8h\n"
-    "ldr q4, [x23, #0x50]\n"
-    "ldr x20, [x13, #0x98]\n"
-    "fmla v24.8h, v6.8h, v22.8h\n"
-    "fmla v20.8h, v1.8h, v17.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "ldr q1, [x23, #0x20]\n"
-    "fmla v19.8h, v2.8h, v16.8h\n"
-    "fmla v24.8h, v7.8h, v17.8h\n"
-    "ldr q2, [x23, #0x30]\n"
-    "ldr x20, [x13, #0x90]\n"
-    "fmla v23.8h, v7.8h, v21.8h\n"
-    "fmla v23.8h, v8.8h, v16.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "ldr x20, [x13, #0xa8]\n"
-    "fmla v20.8h, v6.8h, v16.8h\n"
+    "mov v29.16b, v31.16b\n fmla v29.8h, v8.8h, v9.8h\n"
+    "mov v28.16b, v31.16b\n fmla v28.8h, v6.8h, v9.8h\n"
+    "ldr x28, [x15, #0x40]\n"
+    "ldr x21, [x15, #0x48]\n"
+    "ldr x25, [x15, #0x50]\n"
+    "ldr x20, [x15, #0x58]\n"
+    "mov v25.16b, v31.16b\n fmla v25.8h, v2.8h, v9.8h\n"
+    "mov v24.16b, v31.16b\n fmla v24.8h, v0.8h, v9.8h\n"
+    "ldr q31, [x16, #0x0]\n"
+    "ldr x27, [x15, #0x78]\n"
+    "add x9, x9, #0x10\n"
+    "ldr x24, [x15, #0x60]\n"
+    "ldr x26, [x15, #0x68]\n"
+    "fmla v29.8h, v0.8h, v10.8h\n"
+    "fmla v28.8h, v1.8h, v12.8h\n"
+    "ldr q21, [x21, x14]\n"
+    "ldr x23, [x15, #0x88]\n"
+    "ldr x22, [x15, #0x70]\n"
+    "fmla v29.8h, v1.8h, v11.8h\n"
+    "ldr q18, [x28, x14]\n"
+    "ldr x21, [x15, #0x80]\n"
+    "fmla v28.8h, v2.8h, v13.8h\n"
+    "ldr q20, [x25, x14]\n"
+    "ldr x25, [x15, #0x90]\n"
+    "fmla v29.8h, v3.8h, v14.8h\n"
+    "ldr q17, [x20, x14]\n"
+    "ldr x20, [x15, #0x98]\n"
+    "fmla v28.8h, v0.8h, v16.8h\n"
+    "fmla v25.8h, v3.8h, v17.8h\n"
+    "ldr q23, [x23, x14]\n"
+    "fmla v29.8h, v4.8h, v15.8h\n"
+    "ldr q22, [x24, x14]\n"
+    "ldr x24, [x15, #0xa0]\n"
+    "fmla v28.8h, v4.8h, v18.8h\n"
+    "ldr q17, [x26, x14]\n"
+    "ldr x23, [x15, #0xa8]\n"
+    "fmla v25.8h, v0.8h, v22.8h\n"
+    "ldr q0, [x16, #0x10]\n"
+    "fmla v29.8h, v2.8h, v16.8h\n"
+    "ldr q19, [x22, x14]\n"
+    "ldr x22, [x15, #0xb0]\n"
+    "fmla v28.8h, v5.8h, v21.8h\n"
+    "ldr q18, [x21, x14]\n"
+    "ldr x21, [x15, #0xc0]\n"
+    "fmla v25.8h, v4.8h, v17.8h\n"
+    "ldr q21, [x20, x14]\n"
+    "fmla v29.8h, v5.8h, v20.8h\n"
+    "fmla v28.8h, v3.8h, v20.8h\n"
+    "ldr q16, [x27, x14]\n"
+    "ldr x20, [x15, #0xb8]\n"
+    "fmla v24.8h, v4.8h, v16.8h\n"
+    "ldr q20, [x24, x14]\n"
+    "ldr q4, [x16, #0x50]\n"
+    "fmla v29.8h, v6.8h, v22.8h\n"
+    "ldr q17, [x25, x14]\n"
+    "fmla v25.8h, v1.8h, v19.8h\n"
+    "fmla v24.8h, v1.8h, v18.8h\n"
+    "ldr q1, [x16, #0x20]\n"
+    "fmla v28.8h, v7.8h, v18.8h\n"
+    "fmla v29.8h, v7.8h, v19.8h\n"
+    "ldr q16, [x23, x14]\n"
+    "fmla v24.8h, v5.8h, v23.8h\n"
+    "ldr q19, [x22, x14]\n"
+    "fmla v25.8h, v6.8h, v17.8h\n"
+    "ldr q18, [x20, x14]\n"
+    "fmla v28.8h, v8.8h, v21.8h\n"
+    "fmax v29.8h, v29.8h, v26.8h\n"
+    "fmla v24.8h, v2.8h, v21.8h\n"
+    "ldr q17, [x21, x14]\n"
+    "ldr q2, [x16, #0x30]\n"
+    "ldp x27, x26, [x15, #0x0]\n"
+    "add x14, x14, #0x10\n"
+    "ldp x25, x24, [x15, #0x10]\n"
+    "ldp x23, x22, [x15, #0x20]\n"
+    "fmla v25.8h, v7.8h, v20.8h\n"
+    "ldp x21, x20, [x15, #0x30]\n"
+    "fmin v29.8h, v29.8h, v27.8h\n"
+    "ldr q9, [x27, x8]\n"
+    "ldr q10, [x26, x8]\n"
+    "fmla v24.8h, v3.8h, v16.8h\n"
+    "ldr q3, [x16, #0x40]\n"
+    "fmax v28.8h, v28.8h, v26.8h\n"
+    "ldr q12, [x24, x8]\n"
+    "ldr q13, [x23, x8]\n"
+    "fmla v25.8h, v5.8h, v16.8h\n"
+    "ldr q16, [x20, x8]\n"
+    "ldr q5, [x16, #0x60]\n"
+    "str q29, [x13, x9]\n"
+    "fmin v28.8h, v28.8h, v27.8h\n"
+    "fmla v24.8h, v7.8h, v19.8h\n"
+    "ldr q14, [x22, x8]\n"
+    "ldr q7, [x16, #0x80]\n"
+    "fmla v25.8h, v8.8h, v18.8h\n"
+    "str q28, [x12, x9]\n"
+    "fmla v24.8h, v6.8h, v18.8h\n"
+    "ldr q15, [x21, x8]\n"
+    "ldr q6, [x16, #0x70]\n"
+    "fmax v25.8h, v25.8h, v26.8h\n"
+    "fmla v24.8h, v8.8h, v17.8h\n"
+    "ldr q11, [x25, x8]\n"
+    "ldr q8, [x16, #0x90]\n"
+    "add x8, x8, #0x10\n"
+    "add x16, x16, #0xa0\n"
+    "cmp x8, x17, LSL #4\n"
+    "fmin v25.8h, v25.8h, v27.8h\n"
     "fmax v24.8h, v24.8h, v26.8h\n"
-    "ldr q17, [x20, x28]\n"
-    "ldr x20, [x13, #0xa0]\n"
-    "fmla v19.8h, v3.8h, v17.8h\n"
-    "fmax v23.8h, v23.8h, v26.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "ldr q3, [x23, #0x40]\n"
-    "fmla v20.8h, v7.8h, v16.8h\n"
-    "fmla v20.8h, v5.8h, v17.8h\n"
-    "ldr q5, [x23, #0x60]\n"
-    "ldr x20, [x13, #0xb0]\n"
-    "add x22, x22, #0x10\n"
     "fmin v24.8h, v24.8h, v27.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "ldr x20, [x13, #0xb8]\n"
-    "fmla v19.8h, v7.8h, v16.8h\n"
-    "fmin v23.8h, v23.8h, v27.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "ldr q7, [x23, #0x80]\n"
-    "fmla v19.8h, v6.8h, v16.8h\n"
-    "fmla v20.8h, v8.8h, v16.8h\n"
-    "ldr q6, [x23, #0x70]\n"
-    "ldr x20, [x13, #0xc0]\n"
-    "fmax v20.8h, v20.8h, v26.8h\n"
-    "fmin v20.8h, v20.8h, v27.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v19.8h, v8.8h, v16.8h\n"
-    "ldr q8, [x23, #0x90]\n"
-    "fmax v19.8h, v19.8h, v26.8h\n"
-    "ldp x21, x20, [x13, #0x0]\n"
-    "ldr q9, [x21, x25]\n"
-    "fmin v19.8h, v19.8h, v27.8h\n"
-    "add x28, x28, #0x10\n"
-    "ldr q10, [x20, x25]\n"
-    "ldp x21, x20, [x13, #0x10]\n"
-    "str q24, [x12, x22]\n"
-    "add x23, x23, #0xa0\n"
-    "ldr q11, [x21, x25]\n"
-    "ldr q12, [x20, x25]\n"
-    "str q23, [x11, x22]\n"
-    "ldp x21, x20, [x13, #0x20]\n"
-    "ldr q13, [x21, x25]\n"
-    "str q20, [x10, x22]\n"
-    "ldr q14, [x20, x25]\n"
-    "ldp x21, x20, [x13, #0x30]\n"
-    "str q19, [x9, x22]\n"
-    "ldr q15, [x21, x25]\n"
-    "ldr q16, [x20, x25]\n"
-    "add x25, x25, #0x10\n"
-    "cmp x25, x24, LSL #4\n"
+    "str q25, [x11, x9]\n"
+    "str q24, [x10, x9]\n"
     "blt 1b\n"
     "2:"  // Channel tail
-    "mov v25.16b, v31.16b\n fmla v25.8h, v8.8h, v9.8h\n"
-    "mov v24.16b, v31.16b\n fmla v24.8h, v6.8h, v9.8h\n"
-    "ldr x21, [x13, #0x40]\n"
-    "ldr x20, [x13, #0x48]\n"
-    "fmla v25.8h, v0.8h, v10.8h\n"
-    "fmla v24.8h, v1.8h, v12.8h\n"
-    "ldr q20, [x20, x28]\n"
-    "ldr x20, [x13, #0x50]\n"
-    "fmla v25.8h, v1.8h, v11.8h\n"
-    "ldr q18, [x21, x28]\n"
-    "fmla v24.8h, v2.8h, v13.8h\n"
-    "ldr q19, [x20, x28]\n"
-    "fmla v25.8h, v3.8h, v14.8h\n"
-    "fmla v24.8h, v0.8h, v16.8h\n"
-    "ldr x20, [x13, #0x58]\n"
-    "ldr q17, [x20, x28]\n"
-    "fmla v25.8h, v4.8h, v15.8h\n"
-    "fmla v24.8h, v4.8h, v18.8h\n"
-    "ldr x21, [x13, #0x78]\n"
-    "ldr x20, [x13, #0x60]\n"
-    "ldr q23, [x20, x28]\n"
-    "fmla v25.8h, v2.8h, v16.8h\n"
-    "fmla v24.8h, v5.8h, v20.8h\n"
-    "ldr x20, [x13, #0x80]\n"
-    "ldr q22, [x20, x28]\n"
-    "mov v21.16b, v31.16b\n fmla v21.8h, v2.8h, v9.8h\n"
-    "mov v20.16b, v31.16b\n fmla v20.8h, v0.8h, v9.8h\n"
-    "ldr x20, [x13, #0x68]\n"
-    "ldr q18, [x20, x28]\n"
-    "fmla v25.8h, v5.8h, v19.8h\n"
+    "mov v28.16b, v31.16b\n fmla v28.8h, v8.8h, v9.8h\n"
+    "mov v29.16b, v31.16b\n fmla v29.8h, v6.8h, v9.8h\n"
+    "ldr x28, [x15, #0x40]\n"
+    "ldr x20, [x15, #0x48]\n"
+    "ldr x26, [x15, #0x50]\n"
+    "ldr x25, [x15, #0x58]\n"
+    "mov v25.16b, v31.16b\n fmla v25.8h, v2.8h, v9.8h\n"
+    "mov v24.16b, v31.16b\n fmla v24.8h, v0.8h, v9.8h\n"
+    "ldr x27, [x15, #0x78]\n"
+    "ldr x24, [x15, #0x60]\n"
+    "add x9, x9, #0x10\n"
+    "ldr x23, [x15, #0x68]\n"
+    "ldr x22, [x15, #0x70]\n"
+    "fmla v28.8h, v0.8h, v10.8h\n"
+    "fmla v29.8h, v1.8h, v12.8h\n"
+    "ldr q21, [x20, x14]\n"
+    "ldr x21, [x15, #0x88]\n"
+    "fmla v28.8h, v1.8h, v11.8h\n"
+    "ldr q18, [x28, x14]\n"
+    "ldr x20, [x15, #0x80]\n"
+    "fmla v29.8h, v2.8h, v13.8h\n"
+    "ldr q20, [x26, x14]\n"
+    "ldr x26, [x15, #0x90]\n"
+    "fmla v28.8h, v3.8h, v14.8h\n"
+    "ldr q17, [x25, x14]\n"
+    "ldr x25, [x15, #0x98]\n"
+    "fmla v29.8h, v0.8h, v16.8h\n"
+    "fmla v28.8h, v4.8h, v15.8h\n"
+    "ldr q23, [x24, x14]\n"
+    "ldr x24, [x15, #0xa0]\n"
+    "fmla v25.8h, v3.8h, v17.8h\n"
+    "ldr q22, [x21, x14]\n"
+    "fmla v29.8h, v4.8h, v18.8h\n"
+    "ldr q19, [x23, x14]\n"
+    "ldr x23, [x15, #0xa8]\n"
+    "fmla v28.8h, v2.8h, v16.8h\n"
+    "ldr q18, [x22, x14]\n"
+    "ldr x22, [x15, #0xb0]\n"
+    "fmla v25.8h, v0.8h, v23.8h\n"
+    "fmla v29.8h, v5.8h, v21.8h\n"
+    "ldr q17, [x20, x14]\n"
+    "ldr x21, [x15, #0xc0]\n"
+    "fmla v28.8h, v5.8h, v20.8h\n"
+    "fmla v29.8h, v3.8h, v20.8h\n"
+    "ldr q16, [x27, x14]\n"
+    "ldr x20, [x15, #0xb8]\n"
+    "fmla v24.8h, v4.8h, v16.8h\n"
+    "ldr q21, [x24, x14]\n"
+    "fmla v25.8h, v4.8h, v19.8h\n"
+    "ldr q20, [x25, x14]\n"
+    "fmla v28.8h, v6.8h, v23.8h\n"
+    "ldr q16, [x26, x14]\n"
+    "fmla v29.8h, v7.8h, v17.8h\n"
+    "fmla v24.8h, v1.8h, v17.8h\n"
+    "fmla v25.8h, v1.8h, v18.8h\n"
+    "fmla v28.8h, v7.8h, v18.8h\n"
+    "ldr q19, [x23, x14]\n"
+    "fmla v29.8h, v8.8h, v20.8h\n"
+    "fmla v24.8h, v5.8h, v22.8h\n"
+    "ldr q18, [x22, x14]\n"
+    "fmla v25.8h, v6.8h, v16.8h\n"
+    "ldr q17, [x20, x14]\n"
+    "fmax v28.8h, v28.8h, v26.8h\n"
+    "fmax v29.8h, v29.8h, v26.8h\n"
+    "fmla v24.8h, v2.8h, v20.8h\n"
+    "ldr q16, [x21, x14]\n"
+    "add x14, x14, #0x10\n"
+    "fmla v25.8h, v7.8h, v21.8h\n"
+    "fmin v28.8h, v28.8h, v27.8h\n"
+    "fmin v29.8h, v29.8h, v27.8h\n"
     "fmla v24.8h, v3.8h, v19.8h\n"
-    "ldr q16, [x21, x28]\n"
-    "fmla v21.8h, v3.8h, v17.8h\n"
-    "fmla v20.8h, v4.8h, v16.8h\n"
-    "ldr x20, [x13, #0x88]\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v21.8h, v0.8h, v23.8h\n"
-    "fmla v20.8h, v1.8h, v22.8h\n"
-    "ldr x20, [x13, #0x70]\n"
-    "ldr q17, [x20, x28]\n"
-    "ldr x20, [x13, #0x98]\n"
-    "fmla v21.8h, v4.8h, v18.8h\n"
-    "ldr q19, [x20, x28]\n"
-    "fmla v20.8h, v5.8h, v16.8h\n"
-    "fmla v25.8h, v6.8h, v23.8h\n"
-    "ldr x20, [x13, #0x90]\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v21.8h, v1.8h, v17.8h\n"
-    "ldr x20, [x13, #0xa8]\n"
-    "fmla v20.8h, v2.8h, v19.8h\n"
-    "fmla v25.8h, v7.8h, v17.8h\n"
-    "ldr q18, [x20, x28]\n"
-    "ldr x20, [x13, #0xa0]\n"
-    "ldr q17, [x20, x28]\n"
-    "fmla v21.8h, v6.8h, v16.8h\n"
-    "fmla v20.8h, v3.8h, v18.8h\n"
-    "ldr x20, [x13, #0xb0]\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v21.8h, v7.8h, v17.8h\n"
-    "fmla v20.8h, v7.8h, v16.8h\n"
-    "ldr x20, [x13, #0xb8]\n"
-    "ldr q17, [x20, x28]\n"
-    "fmla v24.8h, v7.8h, v22.8h\n"
-    "fmla v21.8h, v5.8h, v18.8h\n"
-    "ldr x20, [x13, #0xc0]\n"
-    "fmla v20.8h, v6.8h, v17.8h\n"
-    "fmla v24.8h, v8.8h, v19.8h\n"
-    "ldr q16, [x20, x28]\n"
-    "fmla v21.8h, v8.8h, v17.8h\n"
-    "fmla v20.8h, v8.8h, v16.8h\n"
+    "str q28, [x13, x9]\n"
+    "fmla v25.8h, v5.8h, v19.8h\n"
+    "str q29, [x12, x9]\n"
+    "fmla v24.8h, v7.8h, v18.8h\n"
+    "fmla v25.8h, v8.8h, v17.8h\n"
+    "fmla v24.8h, v6.8h, v17.8h\n"
     "fmax v25.8h, v25.8h, v26.8h\n"
-    "add x22, x22, #0x10\n"
-    "fmax v24.8h, v24.8h, v26.8h\n"
-    "fmax v21.8h, v21.8h, v26.8h\n"
-    "add x28, x28, #0x10\n"
-    "fmax v20.8h, v20.8h, v26.8h\n"
     "fmin v25.8h, v25.8h, v27.8h\n"
-    "str q25, [x12, x22]\n"
+    "fmla v24.8h, v8.8h, v16.8h\n"
+    "str q25, [x11, x9]\n"
+    "fmax v24.8h, v24.8h, v26.8h\n"
     "fmin v24.8h, v24.8h, v27.8h\n"
-    "fmin v21.8h, v21.8h, v27.8h\n"
-    "str q24, [x11, x22]\n"
-    "fmin v20.8h, v20.8h, v27.8h\n"
-    "str q21, [x10, x22]\n"
-    "str q20, [x9, x22]\n"
+    "str q24, [x10, x9]\n"
     "3:"  // Oddments
     "tst %x[n_channels], #0x7\n"
     "beq 80f\n"
-    "ldr q31, [x23, #0x0]\n"
-    "ldr q0, [x23, #0x10]\n"
-    "mov x20, x28\n"
+    "ldr q31, [x16, #0x0]\n"
+    "ldr q0, [x16, #0x10]\n"
+    "mov x20, x14\n"
+    "ldr q1, [x16, #0x20]\n"
+    "ldr q2, [x16, #0x30]\n"
+    "ldr q3, [x16, #0x40]\n"
+    "ldr q4, [x16, #0x50]\n"
+    "ldr q5, [x16, #0x60]\n"
+    "ldr q6, [x16, #0x70]\n"
+    "add x13, x13, x20\n"
     "add x12, x12, x20\n"
-    "ldr q1, [x23, #0x20]\n"
-    "ldr q2, [x23, #0x30]\n"
+    "ldr q7, [x16, #0x80]\n"
+    "ldr q8, [x16, #0x90]\n"
     "add x11, x11, x20\n"
     "add x10, x10, x20\n"
-    "ldr q3, [x23, #0x40]\n"
-    "ldr q4, [x23, #0x50]\n"
-    "add x9, x9, x20\n"
-    "ldr q5, [x23, #0x60]\n"
-    "ldr q6, [x23, #0x70]\n"
-    "ldr q7, [x23, #0x80]\n"
-    "ldr q8, [x23, #0x90]\n"
-    "ldr x27, [x13, #0x0]\n"
-    "ldr x26, [x13, #0x8]\n"
-    "add x27, x27, x28\n"
-    "add x26, x26, x28\n"
-    "ldr x25, [x13, #0x10]\n"
-    "ldr x24, [x13, #0x18]\n"
-    "add x25, x25, x28\n"
-    "add x24, x24, x28\n"
-    "ldr x23, [x13, #0x20]\n"
-    "ldr x22, [x13, #0x28]\n"
-    "add x23, x23, x28\n"
-    "add x22, x22, x28\n"
-    "ldr x21, [x13, #0x30]\n"
-    "ldr x20, [x13, #0x38]\n"
-    "add x21, x21, x28\n"
-    "add x20, x20, x28\n"
+    "ldr x27, [x15, #0x0]\n"
+    "ldr x26, [x15, #0x8]\n"
+    "ldr x25, [x15, #0x10]\n"
+    "ldr x24, [x15, #0x18]\n"
+    "ldr x23, [x15, #0x20]\n"
+    "ldr x22, [x15, #0x28]\n"
+    "ldr x21, [x15, #0x30]\n"
+    "ldr x20, [x15, #0x38]\n"
+    "add x27, x27, x14\n"
+    "add x26, x26, x14\n"
+    "add x25, x25, x14\n"
+    "add x24, x24, x14\n"
+    "add x23, x23, x14\n"
+    "add x22, x22, x14\n"
+    "add x21, x21, x14\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 5f\n"
     "ld1 { v9.d }[0], [x27], #0x8\n"
     "ld1 { v10.d }[0], [x26], #0x8\n"
@@ -426,19 +426,19 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "ld1 { v16.h }[0], [x20], #0x2\n"
     "7:"  // Oddments: Load inputs (2, 2), (0, 0), (0, 1), (0, 3), (0, 4), (1, 0), (1, 1), (0, 2): Bit 2: End
     "mov v28.16b, v31.16b\n fmla v28.8h, v8.8h, v9.8h\n"
-    "fmla v28.8h, v0.8h, v10.8h\n"
-    "ldr x20, [x13, #0x40]\n"
-    "add x20, x20, x28\n"
     "mov v29.16b, v31.16b\n fmla v29.8h, v6.8h, v9.8h\n"
-    "fmla v28.8h, v1.8h, v11.8h\n"
-    "fmla v29.8h, v1.8h, v12.8h\n"
-    "fmla v28.8h, v3.8h, v14.8h\n"
-    "fmla v29.8h, v2.8h, v13.8h\n"
-    "fmla v28.8h, v4.8h, v15.8h\n"
+    "ldr x20, [x15, #0x40]\n"
     "mov v30.16b, v31.16b\n fmla v30.8h, v2.8h, v9.8h\n"
     "fmla v31.8h, v0.8h, v9.8h\n"
-    "fmla v28.8h, v2.8h, v16.8h\n"
+    "add x20, x20, x14\n"
+    "fmla v28.8h, v0.8h, v10.8h\n"
+    "fmla v29.8h, v1.8h, v12.8h\n"
+    "fmla v28.8h, v1.8h, v11.8h\n"
+    "fmla v29.8h, v2.8h, v13.8h\n"
+    "fmla v28.8h, v3.8h, v14.8h\n"
     "fmla v29.8h, v0.8h, v16.8h\n"
+    "fmla v28.8h, v4.8h, v15.8h\n"
+    "fmla v28.8h, v2.8h, v16.8h\n"
     "tbz %x[n_channels], #2, 9f\n"
     "ld1 { v11.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 8f\n"
@@ -459,9 +459,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "10:"  // Oddments: Load input (1, 3): Bit 2: Unset: Bit 1: Unset
     "ld1 { v11.h }[0], [x20], #0x2\n"
     "11:"  // Oddments: Load input (1, 3): Bit 2: End
-    "ldr x20, [x13, #0x48]\n"
+    "ldr x20, [x15, #0x48]\n"
     "fmla v29.8h, v4.8h, v11.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 13f\n"
     "ld1 { v12.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 12f\n"
@@ -482,9 +482,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "14:"  // Oddments: Load input (1, 4): Bit 2: Unset: Bit 1: Unset
     "ld1 { v12.h }[0], [x20], #0x2\n"
     "15:"  // Oddments: Load input (1, 4): Bit 2: End
-    "ldr x20, [x13, #0x50]\n"
+    "ldr x20, [x15, #0x50]\n"
     "fmla v29.8h, v5.8h, v12.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 17f\n"
     "ld1 { v13.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 16f\n"
@@ -505,10 +505,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "18:"  // Oddments: Load input (1, 2): Bit 2: Unset: Bit 1: Unset
     "ld1 { v13.h }[0], [x20], #0x2\n"
     "19:"  // Oddments: Load input (1, 2): Bit 2: End
-    "ldr x20, [x13, #0x58]\n"
+    "ldr x20, [x15, #0x58]\n"
     "fmla v28.8h, v5.8h, v13.8h\n"
     "fmla v29.8h, v3.8h, v13.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 21f\n"
     "ld1 { v14.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 20f\n"
@@ -529,9 +529,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "22:"  // Oddments: Load input (3, 0): Bit 2: Unset: Bit 1: Unset
     "ld1 { v14.h }[0], [x20], #0x2\n"
     "23:"  // Oddments: Load input (3, 0): Bit 2: End
-    "ldr x20, [x13, #0x60]\n"
+    "ldr x20, [x15, #0x60]\n"
     "fmla v30.8h, v3.8h, v14.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 25f\n"
     "ld1 { v15.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 24f\n"
@@ -552,10 +552,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "26:"  // Oddments: Load input (2, 0): Bit 2: Unset: Bit 1: Unset
     "ld1 { v15.h }[0], [x20], #0x2\n"
     "27:"  // Oddments: Load input (2, 0): Bit 2: End
-    "ldr x20, [x13, #0x68]\n"
+    "ldr x20, [x15, #0x68]\n"
     "fmla v28.8h, v6.8h, v15.8h\n"
     "fmla v30.8h, v0.8h, v15.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 29f\n"
     "ld1 { v11.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 28f\n"
@@ -576,9 +576,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "30:"  // Oddments: Load input (3, 1): Bit 2: Unset: Bit 1: Unset
     "ld1 { v11.h }[0], [x20], #0x2\n"
     "31:"  // Oddments: Load input (3, 1): Bit 2: End
-    "ldr x20, [x13, #0x70]\n"
+    "ldr x20, [x15, #0x70]\n"
     "fmla v30.8h, v4.8h, v11.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 33f\n"
     "ld1 { v16.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 32f\n"
@@ -599,10 +599,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "34:"  // Oddments: Load input (2, 1): Bit 2: Unset: Bit 1: Unset
     "ld1 { v16.h }[0], [x20], #0x2\n"
     "35:"  // Oddments: Load input (2, 1): Bit 2: End
-    "ldr x20, [x13, #0x78]\n"
+    "ldr x20, [x15, #0x78]\n"
     "fmla v28.8h, v7.8h, v16.8h\n"
     "fmla v30.8h, v1.8h, v16.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 37f\n"
     "ld1 { v13.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 36f\n"
@@ -623,9 +623,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "38:"  // Oddments: Load input (3, 3): Bit 2: Unset: Bit 1: Unset
     "ld1 { v13.h }[0], [x20], #0x2\n"
     "39:"  // Oddments: Load input (3, 3): Bit 2: End
-    "ldr x20, [x13, #0x80]\n"
+    "ldr x20, [x15, #0x80]\n"
     "fmla v31.8h, v4.8h, v13.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 41f\n"
     "ld1 { v12.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 40f\n"
@@ -646,10 +646,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "42:"  // Oddments: Load input (2, 3): Bit 2: Unset: Bit 1: Unset
     "ld1 { v12.h }[0], [x20], #0x2\n"
     "43:"  // Oddments: Load input (2, 3): Bit 2: End
-    "ldr x20, [x13, #0x88]\n"
+    "ldr x20, [x15, #0x88]\n"
     "fmla v29.8h, v7.8h, v12.8h\n"
     "fmla v31.8h, v1.8h, v12.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 45f\n"
     "ld1 { v14.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 44f\n"
@@ -670,9 +670,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "46:"  // Oddments: Load input (3, 4): Bit 2: Unset: Bit 1: Unset
     "ld1 { v14.h }[0], [x20], #0x2\n"
     "47:"  // Oddments: Load input (3, 4): Bit 2: End
-    "ldr x20, [x13, #0x90]\n"
+    "ldr x20, [x15, #0x90]\n"
     "fmla v31.8h, v5.8h, v14.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 49f\n"
     "ld1 { v15.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 48f\n"
@@ -693,9 +693,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "50:"  // Oddments: Load input (4, 0): Bit 2: Unset: Bit 1: Unset
     "ld1 { v15.h }[0], [x20], #0x2\n"
     "51:"  // Oddments: Load input (4, 0): Bit 2: End
-    "ldr x20, [x13, #0x98]\n"
+    "ldr x20, [x15, #0x98]\n"
     "fmla v30.8h, v6.8h, v15.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 53f\n"
     "ld1 { v11.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 52f\n"
@@ -716,10 +716,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "54:"  // Oddments: Load input (2, 4): Bit 2: Unset: Bit 1: Unset
     "ld1 { v11.h }[0], [x20], #0x2\n"
     "55:"  // Oddments: Load input (2, 4): Bit 2: End
-    "ldr x20, [x13, #0xa0]\n"
+    "ldr x20, [x15, #0xa0]\n"
     "fmla v29.8h, v8.8h, v11.8h\n"
     "fmla v31.8h, v2.8h, v11.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 57f\n"
     "ld1 { v13.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 56f\n"
@@ -740,9 +740,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "58:"  // Oddments: Load input (4, 1): Bit 2: Unset: Bit 1: Unset
     "ld1 { v13.h }[0], [x20], #0x2\n"
     "59:"  // Oddments: Load input (4, 1): Bit 2: End
-    "ldr x20, [x13, #0xa8]\n"
+    "ldr x20, [x15, #0xa8]\n"
     "fmla v30.8h, v7.8h, v13.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 61f\n"
     "ld1 { v16.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 60f\n"
@@ -763,10 +763,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "62:"  // Oddments: Load input (3, 2): Bit 2: Unset: Bit 1: Unset
     "ld1 { v16.h }[0], [x20], #0x2\n"
     "63:"  // Oddments: Load input (3, 2): Bit 2: End
-    "ldr x20, [x13, #0xb0]\n"
+    "ldr x20, [x15, #0xb0]\n"
     "fmla v30.8h, v5.8h, v16.8h\n"
     "fmla v31.8h, v3.8h, v16.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 65f\n"
     "ld1 { v14.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 64f\n"
@@ -787,9 +787,9 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "66:"  // Oddments: Load input (4, 3): Bit 2: Unset: Bit 1: Unset
     "ld1 { v14.h }[0], [x20], #0x2\n"
     "67:"  // Oddments: Load input (4, 3): Bit 2: End
-    "ldr x20, [x13, #0xb8]\n"
+    "ldr x20, [x15, #0xb8]\n"
     "fmla v31.8h, v7.8h, v14.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 69f\n"
     "ld1 { v15.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 68f\n"
@@ -810,10 +810,10 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "70:"  // Oddments: Load input (4, 2): Bit 2: Unset: Bit 1: Unset
     "ld1 { v15.h }[0], [x20], #0x2\n"
     "71:"  // Oddments: Load input (4, 2): Bit 2: End
-    "ldr x20, [x13, #0xc0]\n"
+    "ldr x20, [x15, #0xc0]\n"
     "fmla v30.8h, v8.8h, v15.8h\n"
     "fmla v31.8h, v6.8h, v15.8h\n"
-    "add x20, x20, x28\n"
+    "add x20, x20, x14\n"
     "tbz %x[n_channels], #2, 73f\n"
     "ld1 { v11.d }[0], [x20], #0x8\n"
     "tbz %x[n_channels], #1, 72f\n"
@@ -838,56 +838,56 @@ void a64_fp16_nhwc_3x3_s2_output2x2_mla_depthfirst_indirect_impl(
     "fmax v28.8h, v28.8h, v26.8h\n"
     "fmax v29.8h, v29.8h, v26.8h\n"
     "fmax v30.8h, v30.8h, v26.8h\n"
-    "fmax v31.8h, v31.8h, v26.8h\n"
     "fmin v28.8h, v28.8h, v27.8h\n"
+    "fmax v31.8h, v31.8h, v26.8h\n"
     "fmin v29.8h, v29.8h, v27.8h\n"
     "fmin v30.8h, v30.8h, v27.8h\n"
     "fmin v31.8h, v31.8h, v27.8h\n"
     "tbz %x[n_channels], #2, 77f\n"
-    "st1 { v28.d }[0], [x12], #0x8\n"
-    "st1 { v29.d }[0], [x11], #0x8\n"
-    "st1 { v30.d }[0], [x10], #0x8\n"
-    "st1 { v31.d }[0], [x9], #0x8\n"
+    "st1 { v28.d }[0], [x13], #0x8\n"
+    "st1 { v29.d }[0], [x12], #0x8\n"
+    "st1 { v30.d }[0], [x11], #0x8\n"
+    "st1 { v31.d }[0], [x10], #0x8\n"
     "tbz %x[n_channels], #1, 76f\n"
-    "st1 { v28.s }[2], [x12], #0x4\n"
-    "st1 { v29.s }[2], [x11], #0x4\n"
-    "st1 { v30.s }[2], [x10], #0x4\n"
-    "st1 { v31.s }[2], [x9], #0x4\n"
+    "st1 { v28.s }[2], [x13], #0x4\n"
+    "st1 { v29.s }[2], [x12], #0x4\n"
+    "st1 { v30.s }[2], [x11], #0x4\n"
+    "st1 { v31.s }[2], [x10], #0x4\n"
     "tbz %x[n_channels], #0, 79f\n"
-    "st1 { v28.h }[6], [x12], #0x2\n"
-    "st1 { v29.h }[6], [x11], #0x2\n"
-    "st1 { v30.h }[6], [x10], #0x2\n"
-    "st1 { v31.h }[6], [x9], #0x2\n"
+    "st1 { v28.h }[6], [x13], #0x2\n"
+    "st1 { v29.h }[6], [x12], #0x2\n"
+    "st1 { v30.h }[6], [x11], #0x2\n"
+    "st1 { v31.h }[6], [x10], #0x2\n"
     "b 79f\n"
     "76:"  // Oddments: Store: Bit 2: Bit 1: Unset
     "tbz %x[n_channels], #0, 79f\n"
-    "st1 { v28.h }[4], [x12], #0x2\n"
-    "st1 { v29.h }[4], [x11], #0x2\n"
-    "st1 { v30.h }[4], [x10], #0x2\n"
-    "st1 { v31.h }[4], [x9], #0x2\n"
+    "st1 { v28.h }[4], [x13], #0x2\n"
+    "st1 { v29.h }[4], [x12], #0x2\n"
+    "st1 { v30.h }[4], [x11], #0x2\n"
+    "st1 { v31.h }[4], [x10], #0x2\n"
     "b 79f\n"
     "77:"  // Oddments: Store: Bit 2: Unset
     "tbz %x[n_channels], #1, 78f\n"
-    "st1 { v28.s }[0], [x12], #0x4\n"
-    "st1 { v29.s }[0], [x11], #0x4\n"
-    "st1 { v30.s }[0], [x10], #0x4\n"
-    "st1 { v31.s }[0], [x9], #0x4\n"
+    "st1 { v28.s }[0], [x13], #0x4\n"
+    "st1 { v29.s }[0], [x12], #0x4\n"
+    "st1 { v30.s }[0], [x11], #0x4\n"
+    "st1 { v31.s }[0], [x10], #0x4\n"
     "tbz %x[n_channels], #0, 79f\n"
-    "st1 { v28.h }[2], [x12], #0x2\n"
-    "st1 { v29.h }[2], [x11], #0x2\n"
-    "st1 { v30.h }[2], [x10], #0x2\n"
-    "st1 { v31.h }[2], [x9], #0x2\n"
+    "st1 { v28.h }[2], [x13], #0x2\n"
+    "st1 { v29.h }[2], [x12], #0x2\n"
+    "st1 { v30.h }[2], [x11], #0x2\n"
+    "st1 { v31.h }[2], [x10], #0x2\n"
     "b 79f\n"
     "78:"  // Oddments: Store: Bit 2: Unset: Bit 1: Unset
-    "st1 { v28.h }[0], [x12], #0x2\n"
-    "st1 { v29.h }[0], [x11], #0x2\n"
-    "st1 { v30.h }[0], [x10], #0x2\n"
-    "st1 { v31.h }[0], [x9], #0x2\n"
+    "st1 { v28.h }[0], [x13], #0x2\n"
+    "st1 { v29.h }[0], [x12], #0x2\n"
+    "st1 { v30.h }[0], [x11], #0x2\n"
+    "st1 { v31.h }[0], [x10], #0x2\n"
     "79:"  // Oddments: Store: Bit 2: End
     "80:"  // End
     :
     : [n_channels] "r" ((unsigned long) n_channels), [offsetof_Args_inptrs] "I" (offsetof(Args, inptrs)), [offsetof_args_max] "I" (offsetof(Args, max)), [offsetof_args_min] "I" (offsetof(Args, min)), [offsetof_args_outptrs] "I" (offsetof(Args, outptrs)), [offsetof_args_params] "I" (offsetof(Args, params)), [params_struct] "r" (&params_struct)
-    : "cc", "memory", "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7", "v8", "v9", "v10", "v11", "v12", "v13", "v14", "v15", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v30", "v31", "x9", "x10", "x11", "x12", "x13", "x20", "x21", "x22", "x23", "x24", "x25", "x26", "x27", "x28"
+    : "cc", "memory", "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7", "v8", "v9", "v10", "v11", "v12", "v13", "v14", "v15", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v30", "v31", "x8", "x9", "x10", "x11", "x12", "x13", "x14", "x15", "x16", "x17", "x20", "x21", "x22", "x23", "x24", "x25", "x26", "x27", "x28"
   );
 }
 
