@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, 2023 Arm Limited.
+ * Copyright (c) 2021, 2023-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -47,18 +47,19 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
         size_t output_offset = {};
         size_t input_initial_col = {};
         size_t input_offset = {};
+        void *output_ptr = {};
+        const float *bias = {};
     } ka;
 
     unsigned long flags=0;
-    void *output_ptr;
     void *input_ptr;
 
     if (output_arg.is_indirect) {
-        output_ptr=(void *)(output_arg.indirect.ptr);
+        ka.output_ptr=(void *)(output_arg.indirect.ptr);
         ka.output_offset=output_arg.indirect.offset;
         flags |= 0x4;
     } else {
-        output_ptr=(void *)(output_arg.direct.base);
+        ka.output_ptr=(void *)(output_arg.direct.base);
         ka.output_offset=output_arg.direct.stride;
     }
 
@@ -79,6 +80,7 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
     ka.string_lengths = string_lengths;
     ka.N = N;
     ka.B_ptr = B_ptr;
+    ka.bias = bias;
     switch(act.type) {
         default:
         case Activation::Type::None:
@@ -105,10 +107,10 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "cmp %x[M], #0x2\n"
       "bgt 25f\n"
       "beq 13f\n"
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "2:"  // Height 1: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
@@ -126,8 +128,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "6:"  // Height 1: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 7f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -146,22 +148,22 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "addvl x12, x12, #1\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "ld1rw { z0.s }, p1/Z, [x28]\n"
       "bgt 9b\n"
       "10:"  // Height 1: Multiply loop: Main loop skip
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
-      "addvl x12, x12, #1\n"
       "bne 6b\n"
       "tbz %x[flags], #1, 11f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmax z24.s, p1/M, z24.s, z16.s\n"
@@ -174,23 +176,23 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "bgt 2b\n"
       "b 98f\n"
       "13:"  // Height 2
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "14:"  // Height 2: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 15f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
-      "mov z25.d, z24.d\n"
       "addvl x14, x14, #1\n"
+      "mov z25.d, z24.d\n"
       "b 17f\n"
       "15:"  // Height 2: no bias
       "tbz %x[flags], #0, 16f\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x20, x11, x20, LSL #2\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
+      "add x20, x11, x20, LSL #2\n"
       "ld1w { z25.s }, p0/Z, [x20]\n"
       "b 17f\n"
       "16:"  // Height 2: no accumulate
@@ -200,8 +202,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "18:"  // Height 2: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 19f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -224,28 +226,28 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
       "addvl x12, x12, #1\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "ld1rw { z0.s }, p1/Z, [x28]\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
       "bgt 21b\n"
       "22:"  // Height 2: Multiply loop: Main loop skip
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "bne 18b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
       "tbz %x[flags], #1, 23f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -254,33 +256,33 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "23:"  // Height 2: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
+      "st1w { z25.s }, p0, [x28]\n"
       "24:"  // Height 2: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
       "bgt 14b\n"
       "b 98f\n"
       "25:"  // Height 3
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "26:"  // Height 3: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 27f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "b 29f\n"
       "27:"  // Height 3: no bias
       "tbz %x[flags], #0, 28f\n"
-      "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x21, x11, x20, LSL #2\n"
-      "add x20, x21, x20, LSL #2\n"
+      "ldr x21, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "ld1w { z25.s }, p0/Z, [x21]\n"
+      "add x20, x11, x21, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
       "ld1w { z26.s }, p0/Z, [x20]\n"
       "b 29f\n"
       "28:"  // Height 3: no accumulate
@@ -291,8 +293,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "30:"  // Height 3: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 31f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -319,13 +321,13 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
+      "addvl x12, x12, #1\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
+      "ld1rw { z0.s }, p1/Z, [x28]\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
-      "addvl x12, x12, #1\n"
-      "ld1rw { z0.s }, p1/Z, [x28]\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
       "ld1rw { z2.s }, p1/Z, [x26]\n"
       "bgt 33b\n"
@@ -333,19 +335,19 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "bne 30b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
-      "add x26, x27, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "tbz %x[flags], #1, 35f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -356,37 +358,37 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "35:"  // Height 3: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
       "36:"  // Height 3: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
       "bgt 26b\n"
       "b 98f\n"
       "37:"  // Height 4
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "38:"  // Height 4: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 39f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "mov z27.d, z24.d\n"
       "b 41f\n"
       "39:"  // Height 4: no bias
       "tbz %x[flags], #0, 40f\n"
-      "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x22, x11, x20, LSL #2\n"
-      "add x21, x22, x20, LSL #2\n"
+      "ldr x21, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "add x20, x21, x20, LSL #2\n"
-      "ld1w { z25.s }, p0/Z, [x22]\n"
-      "ld1w { z26.s }, p0/Z, [x21]\n"
+      "add x20, x11, x21, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
+      "ld1w { z26.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
       "ld1w { z27.s }, p0/Z, [x20]\n"
       "b 41f\n"
       "40:"  // Height 4: no accumulate
@@ -398,8 +400,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "42:"  // Height 4: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 43f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -430,38 +432,38 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "add x25, x25, #0x4\n"
-      "fmla z27.s, p1/M, z16.s, z3.s\n"
       "addvl x12, x12, #1\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "ld1rw { z0.s }, p1/Z, [x28]\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
+      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "ld1rw { z2.s }, p1/Z, [x26]\n"
+      "fmla z27.s, p1/M, z16.s, z3.s\n"
       "ld1rw { z3.s }, p1/Z, [x25]\n"
       "bgt 45b\n"
       "46:"  // Height 4: Multiply loop: Main loop skip
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "fmla z27.s, p1/M, z16.s, z3.s\n"
       "bne 42b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "add x26, x27, x20, LSL #2\n"
-      "add x25, x26, x20, LSL #2\n"
       "tbz %x[flags], #1, 47f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -474,41 +476,41 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "47:"  // Height 4: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
-      "st1w { z27.s }, p0, [x25]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
+      "st1w { z27.s }, p0, [x26]\n"
       "48:"  // Height 4: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
       "bgt 38b\n"
       "b 98f\n"
       "49:"  // Height 5
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "50:"  // Height 5: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 51f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "mov z27.d, z24.d\n"
       "mov z28.d, z24.d\n"
       "b 53f\n"
       "51:"  // Height 5: no bias
       "tbz %x[flags], #0, 52f\n"
-      "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x23, x11, x20, LSL #2\n"
-      "add x22, x23, x20, LSL #2\n"
+      "ldr x21, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "add x21, x22, x20, LSL #2\n"
-      "add x20, x21, x20, LSL #2\n"
-      "ld1w { z25.s }, p0/Z, [x23]\n"
-      "ld1w { z26.s }, p0/Z, [x22]\n"
-      "ld1w { z27.s }, p0/Z, [x21]\n"
+      "add x20, x11, x21, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
+      "ld1w { z26.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
+      "ld1w { z27.s }, p0/Z, [x20]\n"
+      "add x20, x20, x21, LSL #2\n"
       "ld1w { z28.s }, p0/Z, [x20]\n"
       "b 53f\n"
       "52:"  // Height 5: no accumulate
@@ -521,8 +523,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "54:"  // Height 5: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 55f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -557,19 +559,19 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "add x25, x25, #0x4\n"
       "add x24, x24, #0x4\n"
-      "fmla z27.s, p1/M, z16.s, z3.s\n"
-      "ld1rw { z0.s }, p1/Z, [x28]\n"
       "addvl x12, x12, #1\n"
-      "fmla z28.s, p1/M, z16.s, z4.s\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
+      "ld1rw { z0.s }, p1/Z, [x28]\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
+      "fmla z26.s, p1/M, z16.s, z2.s\n"
+      "fmla z27.s, p1/M, z16.s, z3.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
       "ld1rw { z2.s }, p1/Z, [x26]\n"
+      "fmla z28.s, p1/M, z16.s, z4.s\n"
       "ld1rw { z3.s }, p1/Z, [x25]\n"
       "ld1rw { z4.s }, p1/Z, [x24]\n"
       "bgt 57b\n"
@@ -577,23 +579,23 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "fmla z27.s, p1/M, z16.s, z3.s\n"
       "fmla z28.s, p1/M, z16.s, z4.s\n"
       "bne 54b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "add x26, x27, x20, LSL #2\n"
       "add x25, x26, x20, LSL #2\n"
-      "add x24, x25, x20, LSL #2\n"
       "tbz %x[flags], #1, 59f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -608,44 +610,44 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "59:"  // Height 5: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
-      "st1w { z27.s }, p0, [x25]\n"
-      "st1w { z28.s }, p0, [x24]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
+      "st1w { z27.s }, p0, [x26]\n"
+      "st1w { z28.s }, p0, [x25]\n"
       "60:"  // Height 5: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
       "bgt 50b\n"
       "b 98f\n"
       "61:"  // Height 6
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "62:"  // Height 6: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 63f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "mov z27.d, z24.d\n"
       "mov z28.d, z24.d\n"
       "mov z29.d, z24.d\n"
       "b 65f\n"
       "63:"  // Height 6: no bias
       "tbz %x[flags], #0, 64f\n"
-      "ldr x24, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x23, x11, x24, LSL #2\n"
-      "add x20, x23, x24, LSL #2\n"
+      "ldr x22, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "add x22, x20, x24, LSL #2\n"
-      "add x21, x22, x24, LSL #2\n"
-      "ld1w { z25.s }, p0/Z, [x23]\n"
+      "add x20, x11, x22, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x22, LSL #2\n"
       "ld1w { z26.s }, p0/Z, [x20]\n"
-      "add x20, x21, x24, LSL #2\n"
-      "ld1w { z27.s }, p0/Z, [x22]\n"
+      "add x20, x20, x22, LSL #2\n"
+      "ld1w { z27.s }, p0/Z, [x20]\n"
+      "add x21, x20, x22, LSL #2\n"
+      "add x20, x21, x22, LSL #2\n"
       "ld1w { z28.s }, p0/Z, [x21]\n"
       "ld1w { z29.s }, p0/Z, [x20]\n"
       "b 65f\n"
@@ -660,8 +662,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "66:"  // Height 6: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 67f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -700,48 +702,48 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "add x25, x25, #0x4\n"
       "add x24, x24, #0x4\n"
-      "fmla z27.s, p1/M, z16.s, z3.s\n"
-      "fmla z28.s, p1/M, z16.s, z4.s\n"
       "add x23, x23, #0x4\n"
       "addvl x12, x12, #1\n"
-      "fmla z29.s, p1/M, z16.s, z5.s\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "ld1rw { z0.s }, p1/Z, [x28]\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
+      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "ld1rw { z2.s }, p1/Z, [x26]\n"
+      "fmla z27.s, p1/M, z16.s, z3.s\n"
+      "fmla z28.s, p1/M, z16.s, z4.s\n"
       "ld1rw { z3.s }, p1/Z, [x25]\n"
       "ld1rw { z4.s }, p1/Z, [x24]\n"
+      "fmla z29.s, p1/M, z16.s, z5.s\n"
       "ld1rw { z5.s }, p1/Z, [x23]\n"
       "bgt 69b\n"
       "70:"  // Height 6: Multiply loop: Main loop skip
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "fmla z27.s, p1/M, z16.s, z3.s\n"
       "fmla z28.s, p1/M, z16.s, z4.s\n"
       "fmla z29.s, p1/M, z16.s, z5.s\n"
       "bne 66b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "add x26, x27, x20, LSL #2\n"
       "add x25, x26, x20, LSL #2\n"
       "add x24, x25, x20, LSL #2\n"
-      "add x23, x24, x20, LSL #2\n"
       "tbz %x[flags], #1, 71f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -758,29 +760,29 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "71:"  // Height 6: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
-      "st1w { z27.s }, p0, [x25]\n"
-      "st1w { z28.s }, p0, [x24]\n"
-      "st1w { z29.s }, p0, [x23]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
+      "st1w { z27.s }, p0, [x26]\n"
+      "st1w { z28.s }, p0, [x25]\n"
+      "st1w { z29.s }, p0, [x24]\n"
       "72:"  // Height 6: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
       "bgt 62b\n"
       "b 98f\n"
       "73:"  // Height 7
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "74:"  // Height 7: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 75f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "mov z27.d, z24.d\n"
       "mov z28.d, z24.d\n"
       "mov z29.d, z24.d\n"
@@ -788,17 +790,17 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "b 77f\n"
       "75:"  // Height 7: no bias
       "tbz %x[flags], #0, 76f\n"
-      "ldr x24, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x21, x11, x24, LSL #2\n"
-      "add x20, x21, x24, LSL #2\n"
+      "ldr x23, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "add x23, x20, x24, LSL #2\n"
-      "add x22, x23, x24, LSL #2\n"
-      "ld1w { z25.s }, p0/Z, [x21]\n"
+      "add x20, x11, x23, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x23, LSL #2\n"
       "ld1w { z26.s }, p0/Z, [x20]\n"
-      "add x21, x22, x24, LSL #2\n"
-      "add x20, x21, x24, LSL #2\n"
-      "ld1w { z27.s }, p0/Z, [x23]\n"
+      "add x20, x20, x23, LSL #2\n"
+      "ld1w { z27.s }, p0/Z, [x20]\n"
+      "add x22, x20, x23, LSL #2\n"
+      "add x21, x22, x23, LSL #2\n"
+      "add x20, x21, x23, LSL #2\n"
       "ld1w { z28.s }, p0/Z, [x22]\n"
       "ld1w { z29.s }, p0/Z, [x21]\n"
       "ld1w { z30.s }, p0/Z, [x20]\n"
@@ -815,8 +817,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "78:"  // Height 7: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 79f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -859,25 +861,25 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "add x25, x25, #0x4\n"
       "add x24, x24, #0x4\n"
-      "fmla z27.s, p1/M, z16.s, z3.s\n"
-      "ld1rw { z0.s }, p1/Z, [x28]\n"
       "add x23, x23, #0x4\n"
       "add x22, x22, #0x4\n"
-      "fmla z28.s, p1/M, z16.s, z4.s\n"
-      "fmla z29.s, p1/M, z16.s, z5.s\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
+      "ld1rw { z0.s }, p1/Z, [x28]\n"
       "addvl x12, x12, #1\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
+      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
-      "fmla z30.s, p1/M, z16.s, z6.s\n"
+      "fmla z27.s, p1/M, z16.s, z3.s\n"
       "ld1rw { z2.s }, p1/Z, [x26]\n"
+      "fmla z28.s, p1/M, z16.s, z4.s\n"
       "ld1rw { z3.s }, p1/Z, [x25]\n"
+      "fmla z29.s, p1/M, z16.s, z5.s\n"
       "ld1rw { z4.s }, p1/Z, [x24]\n"
+      "fmla z30.s, p1/M, z16.s, z6.s\n"
       "ld1rw { z5.s }, p1/Z, [x23]\n"
       "ld1rw { z6.s }, p1/Z, [x22]\n"
       "bgt 81b\n"
@@ -885,10 +887,10 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "fmla z27.s, p1/M, z16.s, z3.s\n"
       "fmla z28.s, p1/M, z16.s, z4.s\n"
@@ -896,16 +898,16 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "fmla z30.s, p1/M, z16.s, z6.s\n"
       "bne 78b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "add x26, x27, x20, LSL #2\n"
       "add x25, x26, x20, LSL #2\n"
       "add x24, x25, x20, LSL #2\n"
       "add x23, x24, x20, LSL #2\n"
-      "add x22, x23, x20, LSL #2\n"
       "tbz %x[flags], #1, 83f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -924,12 +926,12 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "83:"  // Height 7: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
-      "st1w { z27.s }, p0, [x25]\n"
-      "st1w { z28.s }, p0, [x24]\n"
-      "st1w { z29.s }, p0, [x23]\n"
-      "st1w { z30.s }, p0, [x22]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
+      "st1w { z27.s }, p0, [x26]\n"
+      "st1w { z28.s }, p0, [x25]\n"
+      "st1w { z29.s }, p0, [x24]\n"
+      "st1w { z30.s }, p0, [x23]\n"
       "84:"  // Height 7: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
@@ -937,20 +939,21 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "b 98f\n"
       "85:"  // Height 8
       "ldr x21, [%x[args_ptr], %[offsetof_output_offset]]\n"
+      "ldr x11, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "mov x20, #0x20\n"
-      "mov x14, %x[bias]\n"
+      "ldr x14, [%x[args_ptr], %[offsetof_bias]]\n"
       "ldr x13, [%x[args_ptr], %[offsetof_N]]\n"
       "ldr x12, [%x[args_ptr], %[offsetof_B_ptr]]\n"
-      "mov x11, %x[output_ptr]\n"
-      "madd %x[output_ptr], x21, x20, %x[output_ptr]\n"
+      "madd x20, x21, x20, x11\n"
+      "str x20, [%x[args_ptr], %[offsetof_output_ptr]]\n"
       "86:"  // Height 8: Column loop
       "mov x20, #0x0\n"
       "whilelt p0.s, x20, x13\n"
       "cbz x14, 87f\n"
       "ld1w { z24.s }, p1/Z, [x14]\n"
+      "addvl x14, x14, #1\n"
       "mov z25.d, z24.d\n"
       "mov z26.d, z24.d\n"
-      "addvl x14, x14, #1\n"
       "mov z27.d, z24.d\n"
       "mov z28.d, z24.d\n"
       "mov z29.d, z24.d\n"
@@ -959,20 +962,20 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "b 89f\n"
       "87:"  // Height 8: no bias
       "tbz %x[flags], #0, 88f\n"
-      "ldr x24, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x22, x11, x24, LSL #2\n"
-      "add x21, x22, x24, LSL #2\n"
+      "ldr x23, [%x[args_ptr], %[offsetof_output_offset]]\n"
       "ld1w { z24.s }, p0/Z, [x11]\n"
-      "add x23, x21, x24, LSL #2\n"
-      "add x20, x23, x24, LSL #2\n"
-      "ld1w { z25.s }, p0/Z, [x22]\n"
-      "ld1w { z26.s }, p0/Z, [x21]\n"
-      "add x22, x20, x24, LSL #2\n"
-      "add x21, x22, x24, LSL #2\n"
-      "ld1w { z27.s }, p0/Z, [x23]\n"
-      "ld1w { z28.s }, p0/Z, [x20]\n"
-      "add x20, x21, x24, LSL #2\n"
-      "ld1w { z29.s }, p0/Z, [x22]\n"
+      "add x20, x11, x23, LSL #2\n"
+      "ld1w { z25.s }, p0/Z, [x20]\n"
+      "add x20, x20, x23, LSL #2\n"
+      "ld1w { z26.s }, p0/Z, [x20]\n"
+      "add x20, x20, x23, LSL #2\n"
+      "ld1w { z27.s }, p0/Z, [x20]\n"
+      "add x22, x20, x23, LSL #2\n"
+      "add x20, x22, x23, LSL #2\n"
+      "add x21, x20, x23, LSL #2\n"
+      "ld1w { z28.s }, p0/Z, [x22]\n"
+      "ld1w { z29.s }, p0/Z, [x20]\n"
+      "add x20, x21, x23, LSL #2\n"
       "ld1w { z30.s }, p0/Z, [x21]\n"
       "ld1w { z31.s }, p0/Z, [x20]\n"
       "b 89f\n"
@@ -989,8 +992,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "mov x10, #0x0\n"
       "90:"  // Height 8: String loop
       "ldr x20, [%x[args_ptr], %[offsetof_string_lengths]]\n"
-      "ldr w9, [x20, x10, LSL #0x2]\n"
       "ldr x21, [%x[args_ptr], %[offsetof_input_offset]]\n"
+      "ldr w9, [x20, x10, LSL #0x2]\n"
       "tbz %x[flags], #3, 91f\n"
       "ldr x20, [%x[input_ptr], x10, LSL #0x3]\n"
       "add x20, x20, x21, LSL #3\n"
@@ -1037,28 +1040,28 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x28, x28, #0x4\n"
       "subs x9, x9, #0x1\n"
-      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "add x27, x27, #0x4\n"
       "add x26, x26, #0x4\n"
-      "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "fmla z26.s, p1/M, z16.s, z2.s\n"
       "add x25, x25, #0x4\n"
       "add x24, x24, #0x4\n"
-      "fmla z27.s, p1/M, z16.s, z3.s\n"
-      "fmla z28.s, p1/M, z16.s, z4.s\n"
       "add x23, x23, #0x4\n"
       "add x22, x22, #0x4\n"
-      "fmla z29.s, p1/M, z16.s, z5.s\n"
+      "fmla z24.s, p1/M, z16.s, z0.s\n"
       "ld1rw { z0.s }, p1/Z, [x28]\n"
       "add x21, x21, #0x4\n"
       "addvl x12, x12, #1\n"
+      "fmla z25.s, p1/M, z16.s, z1.s\n"
       "ld1rw { z1.s }, p1/Z, [x27]\n"
+      "fmla z26.s, p1/M, z16.s, z2.s\n"
+      "ld1rw { z2.s }, p1/Z, [x26]\n"
+      "fmla z27.s, p1/M, z16.s, z3.s\n"
+      "ld1rw { z3.s }, p1/Z, [x25]\n"
+      "fmla z28.s, p1/M, z16.s, z4.s\n"
+      "ld1rw { z4.s }, p1/Z, [x24]\n"
+      "fmla z29.s, p1/M, z16.s, z5.s\n"
+      "ld1rw { z5.s }, p1/Z, [x23]\n"
       "fmla z30.s, p1/M, z16.s, z6.s\n"
       "fmla z31.s, p1/M, z16.s, z7.s\n"
-      "ld1rw { z2.s }, p1/Z, [x26]\n"
-      "ld1rw { z3.s }, p1/Z, [x25]\n"
-      "ld1rw { z4.s }, p1/Z, [x24]\n"
-      "ld1rw { z5.s }, p1/Z, [x23]\n"
       "ld1rw { z6.s }, p1/Z, [x22]\n"
       "ld1rw { z7.s }, p1/Z, [x21]\n"
       "bgt 93b\n"
@@ -1066,10 +1069,10 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "ldr w20, [%x[args_ptr], %[offsetof_num_strings]]\n"
       "ld1w { z16.s }, p1/Z, [x12]\n"
       "add x10, x10, #0x1\n"
+      "addvl x12, x12, #1\n"
       "cmp x10, x20\n"
       "fmla z24.s, p1/M, z16.s, z0.s\n"
       "fmla z25.s, p1/M, z16.s, z1.s\n"
-      "addvl x12, x12, #1\n"
       "fmla z26.s, p1/M, z16.s, z2.s\n"
       "fmla z27.s, p1/M, z16.s, z3.s\n"
       "fmla z28.s, p1/M, z16.s, z4.s\n"
@@ -1078,17 +1081,17 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "fmla z31.s, p1/M, z16.s, z7.s\n"
       "bne 90b\n"
       "ldr x20, [%x[args_ptr], %[offsetof_output_offset]]\n"
-      "add x27, x11, x20, LSL #2\n"
+      "add x28, x11, x20, LSL #2\n"
+      "add x27, x28, x20, LSL #2\n"
       "add x26, x27, x20, LSL #2\n"
       "add x25, x26, x20, LSL #2\n"
       "add x24, x25, x20, LSL #2\n"
       "add x23, x24, x20, LSL #2\n"
       "add x22, x23, x20, LSL #2\n"
-      "add x21, x22, x20, LSL #2\n"
       "tbz %x[flags], #1, 95f\n"
-      "add x20, %x[args_ptr], %[offset_max]\n"
-      "ld1rw { z17.s }, p1/Z, [x20]\n"
+      "add x21, %x[args_ptr], %[offset_max]\n"
       "add x20, %x[args_ptr], %[offset_min]\n"
+      "ld1rw { z17.s }, p1/Z, [x21]\n"
       "ld1rw { z16.s }, p1/Z, [x20]\n"
       "fmin z24.s, p1/M, z24.s, z17.s\n"
       "fmin z25.s, p1/M, z25.s, z17.s\n"
@@ -1109,13 +1112,13 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "95:"  // Height 8: No activation
       "st1w { z24.s }, p0, [x11]\n"
       "addvl x11, x11, #1\n"
-      "st1w { z25.s }, p0, [x27]\n"
-      "st1w { z26.s }, p0, [x26]\n"
-      "st1w { z27.s }, p0, [x25]\n"
-      "st1w { z28.s }, p0, [x24]\n"
-      "st1w { z29.s }, p0, [x23]\n"
-      "st1w { z30.s }, p0, [x22]\n"
-      "st1w { z31.s }, p0, [x21]\n"
+      "st1w { z25.s }, p0, [x28]\n"
+      "st1w { z26.s }, p0, [x27]\n"
+      "st1w { z27.s }, p0, [x26]\n"
+      "st1w { z28.s }, p0, [x25]\n"
+      "st1w { z29.s }, p0, [x24]\n"
+      "st1w { z30.s }, p0, [x23]\n"
+      "st1w { z31.s }, p0, [x22]\n"
       "96:"  // Height 8: Writeback done
       "decw x13\n"
       "cmp x13, XZR\n"
@@ -1132,8 +1135,8 @@ void sve_hybrid_fp32_mla_8x1VL_a64fx (
       "madd %x[input_ptr], x20, x21, %x[input_ptr]\n"
       "b 1b\n"
       "98:"  // Exit
-      : [M] "+&r" (M), [input_ptr] "+&r" (input_ptr), [output_ptr] "+&r" (output_ptr)
-      : [args_ptr] "r" (&ka), [bias] "r" (bias), [flags] "r" (flags), [offset_max] "I" (offsetof(KernelArgs, maxval)), [offset_min] "I" (offsetof(KernelArgs, minval)), [offsetof_B_ptr] "I" (offsetof(KernelArgs, B_ptr)), [offsetof_N] "I" (offsetof(KernelArgs, N)), [offsetof_input_initial_col] "I" (offsetof(KernelArgs, input_initial_col)), [offsetof_input_offset] "I" (offsetof(KernelArgs, input_offset)), [offsetof_num_strings] "I" (offsetof(KernelArgs, num_strings)), [offsetof_output_offset] "I" (offsetof(KernelArgs, output_offset)), [offsetof_string_lengths] "I" (offsetof(KernelArgs, string_lengths))
+      : [M] "+&r" (M), [input_ptr] "+&r" (input_ptr)
+      : [args_ptr] "r" (&ka), [flags] "r" (flags), [offset_max] "I" (offsetof(KernelArgs, maxval)), [offset_min] "I" (offsetof(KernelArgs, minval)), [offsetof_B_ptr] "I" (offsetof(KernelArgs, B_ptr)), [offsetof_N] "I" (offsetof(KernelArgs, N)), [offsetof_bias] "I" (offsetof(KernelArgs, bias)), [offsetof_input_initial_col] "I" (offsetof(KernelArgs, input_initial_col)), [offsetof_input_offset] "I" (offsetof(KernelArgs, input_offset)), [offsetof_num_strings] "I" (offsetof(KernelArgs, num_strings)), [offsetof_output_offset] "I" (offsetof(KernelArgs, output_offset)), [offsetof_output_ptr] "I" (offsetof(KernelArgs, output_ptr)), [offsetof_string_lengths] "I" (offsetof(KernelArgs, string_lengths))
       : "cc", "memory", "p0", "p1", "x9", "x10", "x11", "x12", "x13", "x14", "x20", "x21", "x22", "x23", "x24", "x25", "x26", "x27", "x28", "z0", "z1", "z2", "z3", "z4", "z5", "z6", "z7", "z16", "z17", "z24", "z25", "z26", "z27", "z28", "z29", "z30", "z31"
     );
 }
