@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022 Arm Limited.
+ * Copyright (c) 2020-2022,2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,16 +21,36 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_BFLOAT16_H
-#define ARM_COMPUTE_BFLOAT16_H
+#ifndef ACL_SUPPORT_BFLOAT16_H
+#define ACL_SUPPORT_BFLOAT16_H
 
 #include <cstdint>
 #include <cstring>
-
+#include <ostream>
 namespace arm_compute
 {
 namespace
 {
+/** Convert float to bfloat16 in a portable way that works on older hardware
+ *
+ * @param[in] v Floating-point value to convert to bfloat
+ *
+ * @return Converted value
+ */
+inline uint16_t portable_float_to_bf16(const float v)
+{
+    const uint32_t *fromptr = reinterpret_cast<const uint32_t *>(&v);
+    uint16_t        res     = (*fromptr >> 16);
+    const uint16_t  error   = (*fromptr & 0x0000ffff);
+    uint16_t        bf_l    = res & 0x0001;
+
+    if ((error > 0x8000) || ((error == 0x8000) && (bf_l != 0)))
+    {
+        res += 1;
+    }
+    return res;
+}
+
 /** Convert float to bfloat16
  *
  * @param[in] v Floating-point value to convert to bfloat
@@ -39,27 +59,20 @@ namespace
  */
 inline uint16_t float_to_bf16(const float v)
 {
-    const uint32_t *fromptr = reinterpret_cast<const uint32_t *>(&v);
 #if defined(ARM_COMPUTE_ENABLE_BF16)
-    uint16_t res;
+    const uint32_t *fromptr = reinterpret_cast<const uint32_t *>(&v);
+    uint16_t        res;
 
-    __asm __volatile(
-        "ldr    s0, [%[fromptr]]\n"
-        ".inst    0x1e634000\n" // BFCVT h0, s0
-        "str    h0, [%[toptr]]\n"
-        :
-        : [fromptr] "r"(fromptr), [toptr] "r"(&res)
-        : "v0", "memory");
-#else  /* defined(ARM_COMPUTE_ENABLE_BF16) */
-    uint16_t       res   = (*fromptr >> 16);
-    const uint16_t error = (*fromptr & 0x0000ffff);
-    uint16_t       bf_l  = res & 0x0001;
-    if((error > 0x8000) || ((error == 0x8000) && (bf_l != 0)))
-    {
-        res += 1;
-    }
-#endif /* defined(ARM_COMPUTE_ENABLE_BF16) */
+    __asm __volatile("ldr    s0, [%[fromptr]]\n"
+                     ".inst    0x1e634000\n" // BFCVT h0, s0
+                     "str    h0, [%[toptr]]\n"
+                     :
+                     : [fromptr] "r"(fromptr), [toptr] "r"(&res)
+                     : "v0", "memory");
     return res;
+#else  /* defined(ARM_COMPUTE_ENABLE_BF16) */
+    return portable_float_to_bf16(v);
+#endif /* defined(ARM_COMPUTE_ENABLE_BF16) */
 }
 
 /** Convert bfloat16 to float
@@ -75,25 +88,32 @@ inline float bf16_to_float(const uint16_t &v)
     memcpy(&fp, &lv, sizeof(lv));
     return fp;
 }
-}
+} // namespace
 
 /** Brain floating point representation class */
 class bfloat16 final
 {
 public:
     /** Default Constructor */
-    bfloat16()
-        : value(0)
+    bfloat16() : value(0)
     {
     }
     /** Constructor
      *
      * @param[in] v Floating-point value
      */
-    bfloat16(float v)
-        : value(float_to_bf16(v))
+    explicit bfloat16(float v) : value(float_to_bf16(v))
     {
     }
+    /** Constructor
+     *
+     * @param[in] v        Floating-point value
+     * @param[in] portable bool to indicate the conversion is to be done in a backward compatible way
+     */
+    bfloat16(float v, bool portable) : value(0)
+    {
+        value = portable ? portable_float_to_bf16(v) : float_to_bf16(v);
+    }
     /** Assignment operator
      *
      * @param[in] v Floating point value to assign
@@ -134,8 +154,16 @@ public:
         return val;
     }
 
+    bfloat16 &operator+=(float v)
+    {
+        value = float_to_bf16(bf16_to_float(value) + v);
+        return *this;
+    }
+
+    friend std::ostream &operator<<(std::ostream &os, const bfloat16 &arg);
+
 private:
     uint16_t value;
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_BFLOAT16_H */
+#endif // ACL_SUPPORT_BFLOAT16_H
