@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017 Arm Limited.
+ * Copyright (c) 2017, 2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,13 +24,12 @@
 #ifndef __ARM_COMPUTE_HALF_H__
 #define __ARM_COMPUTE_HALF_H__
 
-#if(__ANDROID__ || BARE_METAL)
-// Android toolchain is broken and doesn't support all CPP11 math functions.
+#if (BARE_METAL)
 #define HALF_ENABLE_CPP11_CMATH 0
-#endif /* __ANDROID__ || BARE_METAL */
+#endif /* BARE_METAL */
 
 // Set style to round to nearest
-#define HALF_ROUND_STYLE 1
+#define HALF_ROUND_STYLE        1
 #define HALF_ROUND_TIES_TO_EVEN 1
 
 #include "half/half.hpp"
