@@ -21,8 +21,11 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_SUPPORT_TOOLCHAINSUPPORT
-#define ARM_COMPUTE_SUPPORT_TOOLCHAINSUPPORT
+#ifndef ACL_SUPPORT_TOOLCHAINSUPPORT_H
+#define ACL_SUPPORT_TOOLCHAINSUPPORT_H
+
+#include "support/Bfloat16.h"
+#include "support/Half.h"
 
 #include <cassert>
 #include <cmath>
@@ -33,9 +36,6 @@
 #include <string>
 #include <type_traits>
 
-#include "support/Bfloat16.h"
-#include "support/Half.h"
-
 #ifndef M_PI
 #define M_PI (3.14159265358979323846)
 #endif // M_PI
@@ -50,7 +50,7 @@ namespace support
 {
 namespace cpp11
 {
-#if(__ANDROID__ || BARE_METAL)
+#if (__ANDROID__ || BARE_METAL)
 template <typename T>
 inline T nearbyint(T value)
 {
@@ -129,11 +129,12 @@ inline T copysign(T x, T y)
  *
  * @return Result floating point value equal to (x*y) + z.c
  */
-template < typename T, typename = typename std::enable_if < std::is_floating_point<T>::value
+template <typename T,
+          typename = typename std::enable_if<std::is_floating_point<T>::value
 #ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
-                                                            || std::is_same<T, float16_t>::value
+                                             || std::is_same<T, float16_t>::value
 #endif // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
-                                                            >::type >
+                                             >::type>
 inline T fma(T x, T y, T z)
 {
     return ::fma(x, y, z);
@@ -151,7 +152,7 @@ inline T fma(T x, T y, T z)
  *          if successful (not including the ending null character), or a negative value if an error occurred.
  */
 template <typename... Ts>
-inline int snprintf(char *s, size_t n, const char *fmt, Ts &&... args)
+inline int snprintf(char *s, size_t n, const char *fmt, Ts &&...args)
 {
     return ::snprintf(s, n, fmt, std::forward<Ts>(args)...);
 }
@@ -183,8 +184,7 @@ inline T nearbyint(T value)
 template <typename T, typename = typename std::enable_if<std::is_floating_point<T>::value>::type>
 inline T round(T value)
 {
-    //Workaround Valgrind's mismatches: when running from Valgrind the call to std::round(-4.500000) == -4.000000 instead of 5.00000
-    return (value < 0.f) ? static_cast<int>(value - 0.5f) : static_cast<int>(value + 0.5f);
+    return std::round(value);
 }
 
 /** Round floating-point value with half value rounding away from zero and cast to long
@@ -244,11 +244,12 @@ inline T copysign(T x, T y)
  *
  * @return Result floating point value equal to (x*y) + z.
  */
-template < typename T, typename = typename std::enable_if < std::is_floating_point<T>::value
+template <typename T,
+          typename = typename std::enable_if<std::is_floating_point<T>::value
 #ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
-                                                            || std::is_same<T, float16_t>::value
+                                             || std::is_same<T, float16_t>::value
 #endif // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
-                                                            >::type >
+                                             >::type>
 inline T fma(T x, T y, T z)
 {
     return std::fma(x, y, z);
@@ -266,7 +267,7 @@ inline T fma(T x, T y, T z)
  *          if successful (not including the ending null character), or a negative value if an error occurred.
  */
 template <typename... Ts>
-inline int snprintf(char *s, std::size_t n, const char *fmt, Ts &&... args)
+inline int snprintf(char *s, std::size_t n, const char *fmt, Ts &&...args)
 {
     return std::snprintf(s, n, fmt, std::forward<Ts>(args)...);
 }
@@ -329,4 +330,4 @@ inline bool signbit(bfloat16 value)
 } // namespace cpp11
 } // namespace support
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_SUPPORT_TOOLCHAINSUPPORT */
+#endif // ACL_SUPPORT_TOOLCHAINSUPPORT_H
