@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2022 Arm Limited.
+ * Copyright (c) 2017-2022, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_TEST_TENSOR_LIBRARY_H
-#define ARM_COMPUTE_TEST_TENSOR_LIBRARY_H
+#ifndef ACL_TESTS_ASSETSLIBRARY_H
+#define ACL_TESTS_ASSETSLIBRARY_H
 
 #include "arm_compute/core/Coordinates.h"
 #include "arm_compute/core/Error.h"
@@ -76,6 +76,12 @@ public:
      */
     std::string path() const;
 
+    /** Set the seed that is used to fill tensors with random values.
+     *
+     * @param[in] the initial random seed to set.
+     */
+    void set_seed(std::random_device::result_type);
+
     /** Seed that is used to fill tensors with random values.
      *
      * @return the initial random seed.
@@ -588,7 +594,6 @@ void AssetsLibrary::fill_with_generator(T &&tensor, const GeneratorFunctionType<
 {
     const bool  is_nhwc = tensor.data_layout() == DataLayout::NHWC;
     TensorShape shape(tensor.shape());
-
     if(is_nhwc)
     {
         // Ensure that the equivalent tensors will be filled for both data layouts
@@ -739,6 +744,7 @@ void AssetsLibrary::fill_tensor_uniform(T &&tensor, std::random_device::result_t
             break;
         }
         case DataType::U16:
+        case DataType::QASYMM16:
         {
             std::uniform_int_distribution<uint16_t> distribution_u16(std::numeric_limits<uint16_t>::lowest(), std::numeric_limits<uint16_t>::max());
             fill(tensor, distribution_u16, seed_offset);
@@ -778,7 +784,7 @@ void AssetsLibrary::fill_tensor_uniform(T &&tensor, std::random_device::result_t
         case DataType::BFLOAT16:
         {
             // It doesn't make sense to check [-inf, inf], so hard code it to a big number
-            arm_compute::utils::uniform_real_distribution_16bit<bfloat16> distribution_bf16{ -1000.f, 1000.f };
+            arm_compute::utils::uniform_real_distribution_16bit<bfloat16> distribution_bf16{ -1000.f, 1000.f, true /* portable */ };
             fill(tensor, distribution_bf16, seed_offset);
             break;
         }
@@ -1057,4 +1063,4 @@ void AssetsLibrary::fill_tensor_value(T &&tensor, D value) const
 }
 } // namespace test
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_TEST_TENSOR_LIBRARY_H */
+#endif // ACL_TESTS_ASSETSLIBRARY_H
