@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2023 Arm Limited.
+ * Copyright (c) 2017-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_TEST_SHAPE_DATASETS_H
-#define ARM_COMPUTE_TEST_SHAPE_DATASETS_H
+#ifndef ACL_TESTS_DATASETS_SHAPEDATASETS_H
+#define ACL_TESTS_DATASETS_SHAPEDATASETS_H
 
 #include "arm_compute/core/TensorShape.h"
 #include "tests/framework/datasets/Datasets.h"
@@ -199,8 +199,8 @@ public:
         : ShapeDataset("Shape",
     {
         // Batch size 1
-        TensorShape{ 3U, 11U },
-                     TensorShape{ 1U, 16U },
+        //TensorShape{ 3U, 11U },
+                     //TensorShape{ 1U, 16U },
                      TensorShape{ 27U, 13U, 7U },
                      TensorShape{ 7U, 7U, 17U, 2U },
                      // Batch size 4 and 2 SIMD iterations
@@ -212,6 +212,44 @@ public:
     }
 };
 
+class SMEMulShapes final : public ShapeDataset
+{
+public:
+    SMEMulShapes()
+        : ShapeDataset("Shape",
+    {
+        // Batch size 1
+        TensorShape{ 6U, 1U },
+        TensorShape{ 128U, 2U},
+        TensorShape{ 128U, 2U, 4U, 2U, 2U} // 5D collapsible case
+    })
+    {
+    }
+};
+
+/** Data set containing pairs of small tensor shapes that are broadcast compatible. */
+class SMEMulShapesBroadcast final : public framework::dataset::ZipDataset<ShapeDataset, ShapeDataset>
+{
+public:
+    SMEMulShapesBroadcast()
+        : ZipDataset<ShapeDataset, ShapeDataset>(
+              ShapeDataset("Shape0",
+    {
+        // NOTE: This does not include x-wise broadcasting.
+        TensorShape{ 9U, 9U },
+        TensorShape{ 256U, 13U, 1U },
+        TensorShape{ 128U, 1U, 5U, 1U },
+    }),
+    ShapeDataset("Shape1",
+    {
+        TensorShape{ 9U, 1U, 2U },
+        TensorShape{ 256U, 1U, 2U },
+        TensorShape{ 128U, 64U, 1U, 3U },
+    }))
+    {
+    }
+};
+
 /** Data set containing small tensor shapes. */
 class SmallShapesNoBatches final : public ShapeDataset
 {
@@ -301,6 +339,30 @@ public:
     }
 };
 
+/** Data set containing pairs of small tensor shapes that are broadcast compatible in non-x dimensions. */
+class SmallShapesNonXBroadcast final : public framework::dataset::ZipDataset<ShapeDataset, ShapeDataset>
+{
+public:
+    SmallShapesNonXBroadcast()
+        : ZipDataset<ShapeDataset, ShapeDataset>(
+    ShapeDataset("Shape0",
+    {
+        TensorShape{ 9U, 9U },
+        TensorShape{ 128U, 1U, 5U, 3U },
+        TensorShape{ 9U, 9U, 3U, 4U },
+        TensorShape{ 1U, 16U, 10U, 2U, 128U }
+    }),
+    ShapeDataset("Shape1",
+    {
+        TensorShape{ 9U, 1U, 2U },
+        TensorShape{ 128U, 64U, 1U, 3U },
+        TensorShape{ 9U, 1U, 3U },
+        TensorShape{ 1U, 1U, 1U, 1U, 128U }
+    }))
+    {
+    }
+};
+
 class TemporaryLimitedSmallShapesBroadcast final : public framework::dataset::ZipDataset<ShapeDataset, ShapeDataset>
 {
 public:
@@ -618,6 +680,21 @@ public:
     }
 };
 
+/** Data set containing tiny 5D tensor shapes. */
+class Tiny5dShapes final : public ShapeDataset
+{
+public:
+    Tiny5dShapes()
+        : ShapeDataset("Shape",
+    {
+        TensorShape{ 2U, 2U, 3U, 4U, 2U },
+                     TensorShape{ 2U, 3U, 4U, 6U, 2U },
+                     TensorShape{ 3U, 2U, 6U, 1U, 2U },
+    })
+    {
+    }
+};
+
 /** Data set containing small 5D tensor shapes. */
 class Small5dShapes final : public ShapeDataset
 {
@@ -1194,7 +1271,34 @@ public:
     }
 };
 
+/** Data set containing large 2D tensor shapes. */
+class Large2DMeanStdDevNormalizationShapes final : public ShapeDataset
+{
+public:
+    Large2DMeanStdDevNormalizationShapes()
+        : ShapeDataset("Shape",
+    {
+        TensorShape{ 1245U, 652U },
+        TensorShape{ 1048576U, 32U }
+    })
+    {
+    }
+};
+
+/** Data set containing SME Stressing shapes for Logistic SME Kernel. */
+class LogisticSMEStressShapesFp32 final : public ShapeDataset
+{
+public:
+    LogisticSMEStressShapesFp32()
+        : ShapeDataset("Shape",
+    {
+        TensorShape{ 130U, 2U },
+        TensorShape{ 256U, 1U },
+    })
+    {
+    }
+};
 } // namespace datasets
 } // namespace test
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_TEST_SHAPE_DATASETS_H */
+#endif // ACL_TESTS_DATASETS_SHAPEDATASETS_H
