@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2021 Arm Limited.
+ * Copyright (c) 2017-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,10 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_TEST_HWC_NAMES
-#define ARM_COMPUTE_TEST_HWC_NAMES
+#ifndef ACL_TESTS_FRAMEWORK_INSTRUMENTS_HWC_NAMES_HPP
+#define ACL_TESTS_FRAMEWORK_INSTRUMENTS_HWC_NAMES_HPP
+
+#include <cstdint>
 
 #ifndef DOXYGEN_SKIP_THIS
 
@@ -3061,4 +3063,4 @@ enum
 
 #endif /* DOXYGEN_SKIP_THIS */
 
-#endif /* ARM_COMPUTE_TEST_HWC_NAMES */
+#endif // ACL_TESTS_FRAMEWORK_INSTRUMENTS_HWC_NAMES_HPP
