@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2020 Arm Limited.
+ * Copyright (c) 2018-2021 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,9 +21,8 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#include "arm_compute/core/CL/kernels/CLIm2ColKernel.h"
 #include "arm_compute/core/Types.h"
-
+#include "src/gpu/cl/kernels/ClIm2ColKernel.h"
 #include "tests/CL/CLAccessor.h"
 #include "tests/CL/Helper.h"
 #include "tests/framework/Asserts.h"
@@ -41,7 +40,7 @@ namespace validation
 TEST_SUITE(CL)
 TEST_SUITE(Im2Col)
 
-using CLIm2Col = CLSynthetizeFunction<CLIm2ColKernel>;
+using ClIm2Col = ClSynthetizeOperatorWithBorder<opencl::kernels::ClIm2ColKernel>;
 
 /** Negative tests
  *
@@ -64,7 +63,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto output    = TensorInfo(TensorShape(9U, 10U, 12U, 2U), 1, DataType::F32);
         const auto conv_size = Size2D(3, 3);
         const bool has_bias  = false;
-        const auto status    = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
+        const auto status    = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -74,7 +73,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto output    = TensorInfo(TensorShape(9U, 80U, 2U), 1, DataType::QASYMM8);
         const auto conv_size = Size2D(3, 3);
         const bool has_bias  = true;
-        const auto status    = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
+        const auto status    = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -85,7 +84,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto conv_size = Size2D(3, 3);
         const auto dilation  = Size2D(0, 1);
         const bool has_bias  = false;
-        const auto status    = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation);
+        const auto status    = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -97,7 +96,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto         dilation   = Size2D(1, 1);
         const bool         has_bias   = false;
         const unsigned int num_groups = 2;
-        const auto         status     = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation, num_groups);
+        const auto         status     = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation, num_groups);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -109,7 +108,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto         dilation   = Size2D(1, 1);
         const bool         has_bias   = false;
         const unsigned int num_groups = 2;
-        const auto         status     = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation, num_groups);
+        const auto         status     = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias, dilation, num_groups);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -119,7 +118,7 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto output    = TensorInfo(TensorShape(9U, 81U, 2U), 1, DataType::F32);
         const auto conv_size = Size2D(3, 3);
         const bool has_bias  = false;
-        const auto status    = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
+        const auto status    = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 
@@ -129,55 +128,16 @@ TEST_CASE(Negative, framework::DatasetMode::ALL)
         const auto output    = TensorInfo(TensorShape(1U, 1U, 1U, 2U), 1, DataType::F32, DataLayout::NHWC);
         const auto conv_size = Size2D(9, 9);
         const bool has_bias  = false;
-        const auto status    = CLIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
+        const auto status    = opencl::kernels::ClIm2ColKernel::validate(&input, &output, conv_size, PadStrideInfo(), has_bias);
         ARM_COMPUTE_EXPECT(bool(status) == false, framework::LogLevel::ERRORS);
     }
 }
 
 template <typename T>
-using CLIm2ColFixture = Im2ColValidationFixture<CLTensor, CLAccessor, CLIm2Col, T, true>;
+using ClIm2ColFixture = Im2ColOpValidationFixture<CLTensor, CLAccessor, ClIm2Col, T, true>;
 
 TEST_SUITE(NHWC)
 
-/** Test that there's no padding added to input or output as part of configure
- *
- * @note 2 elements processed per iteration
- *
- * Three tests will be run:
- *  - Channels are multiple of elements processed
- *  - Channels larger and non multiple of elements used
- *  - Channels smaller and not multiple of elements used
- *
- */
-DATA_TEST_CASE(ValidateZeroPaddingNumElemsPerIterEqual2, framework::DatasetMode::ALL,
-               combine(combine(combine(combine(combine(
-                                                   framework::dataset::make("InputChannel",
-{
-    2, 9, 1,
-}),
-framework::dataset::make("DataType", { DataType::F32 })),
-framework::dataset::make("Kernel", { Size2D(3, 4) })),
-framework::dataset::make("PadStride", { PadStrideInfo(2, 1, 1, 2) })),
-framework::dataset::make("QInfo", { QuantizationInfo() })),
-framework::dataset::make("DataLayout", { DataLayout::NHWC })),
-input_channel, data_type, conv_size, pad_stride_info, qinfo, data_layout)
-{
-    TensorShape input_shape(input_channel, 10U, 30U, 3U);
-    const bool  has_bias = false;
-
-    const auto input_info   = TensorInfo(input_shape, 1, data_type, data_layout);
-    const auto output_shape = compute_im2col_conv_shape(&input_info, conv_size, pad_stride_info, has_bias, Size2D(1U, 1U), true);
-
-    CLTensor input  = create_tensor<CLTensor>(input_shape, data_type, 1, qinfo, data_layout);
-    CLTensor output = create_tensor<CLTensor>(output_shape, data_type, 1, qinfo, data_layout);
-
-    CLIm2ColKernel im2col;
-    im2col.configure(&input, &output, conv_size, pad_stride_info, has_bias);
-
-    // Ensure there're no paddings added at all
-    const bool no_padding = input.info()->padding().empty() && output.info()->padding().empty();
-    ARM_COMPUTE_EXPECT(no_padding, framework::LogLevel::ERRORS);
-}
 /** Test special kernel used for NHWC for 3x3 kernels
  *
  * @note 2 elements processed per iteration
@@ -190,12 +150,12 @@ input_channel, data_type, conv_size, pad_stride_info, qinfo, data_layout)
  *  Kernel tested im2col3x3_nhwc
  */
 FIXTURE_DATA_TEST_CASE(W3x3,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape",
 {
-    TensorShape(2U, 5U, 7U, 2U), TensorShape(3U, 4U, 6U, 2U), TensorShape(1U, 5U, 3U, 2U),
+    TensorShape(5U, 7U, 2U, 2U), TensorShape(4U, 6U, 3U, 2U), TensorShape(5U, 3U, 1U, 2U),
 }),
 framework::dataset::make("DataType", DataType::F32)),
 framework::dataset::make("Kernel", Size2D(3, 3))),
@@ -220,12 +180,12 @@ framework::dataset::make("Groups", 1)))
  *  Kernel tested im2col9x9_nhwc
  */
 FIXTURE_DATA_TEST_CASE(W9x9,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape",
 {
-    TensorShape(2U, 13U, 15U, 2U), TensorShape(3U, 15U, 12U, 2U), TensorShape(1U, 13U, 22U, 2U),
+    TensorShape(13U, 15U, 2U, 2U), TensorShape(15U, 12U, 3U, 2U), TensorShape(13U, 22U, 1U, 2U),
 }),
 framework::dataset::make("DataType", DataType::F32)),
 framework::dataset::make("Kernel", Size2D(9, 9))),
@@ -250,12 +210,12 @@ framework::dataset::make("Groups", 1)))
  *  Kernel tested im2col_generic_nhwc
  */
 FIXTURE_DATA_TEST_CASE(Generic,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape",
 {
-    TensorShape(4U, 13U, 15U, 2U), TensorShape(7U, 15U, 12U, 1U), TensorShape(1U, 5U, 3U, 1U),
+    TensorShape(13U, 15U, 4U, 2U), TensorShape(15U, 12U, 7U, 1U), TensorShape(5U, 3U, 1U, 1U),
 }),
 framework::dataset::make("DataType", DataType::F32)),
 framework::dataset::make("Kernel", Size2D(5, 3))),
@@ -283,7 +243,7 @@ TEST_SUITE(NCHW)
  *  Kernel tested im2col1x1_stridex1_nchw
  */
 FIXTURE_DATA_TEST_CASE(W1x1_Stride1_NoPad,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", { TensorShape(4U, 4U, 3U, 2U), TensorShape(5U, 4U, 3U, 2U), TensorShape(3U, 4U, 3U, 2U) }),
@@ -307,7 +267,7 @@ FIXTURE_DATA_TEST_CASE(W1x1_Stride1_NoPad,
  *  Kernel tested im2col3x3_nchw
  */
 FIXTURE_DATA_TEST_CASE(W3x3,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(4U, 4U, 3U, 2U)),
@@ -331,7 +291,7 @@ FIXTURE_DATA_TEST_CASE(W3x3,
  *  Kernel tested im2col5x5_nchw
  */
 FIXTURE_DATA_TEST_CASE(W5x5,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(7U, 4U, 3U, 2U)),
@@ -357,7 +317,7 @@ FIXTURE_DATA_TEST_CASE(W5x5,
  * Kernel tested im2col11x11_padx0_pady0_nchw
  */
 FIXTURE_DATA_TEST_CASE(W11x11_NoPad,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", { TensorShape(11U, 11U, 2U, 2U), TensorShape(14U, 13U, 1U, 2U) }),
@@ -381,7 +341,7 @@ FIXTURE_DATA_TEST_CASE(W11x11_NoPad,
  * Kernel tested im2col_generic_padx0_pady0_nchw
  */
 FIXTURE_DATA_TEST_CASE(GenericZeroPad,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(13U, 11U, 2U, 2U)),
@@ -407,7 +367,7 @@ TEST_SUITE_END() // NCHW
  * Kernel tested im2col_generic_(nchw|nhwc)
  */
 FIXTURE_DATA_TEST_CASE(Generic,
-                       CLIm2ColFixture<float>,
+                       ClIm2ColFixture<float>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(13U, 11U, 5U, 2U)),
@@ -433,7 +393,7 @@ FIXTURE_DATA_TEST_CASE(Generic,
  *  - im2col9x9_nhwc
  */
 FIXTURE_DATA_TEST_CASE(Quantized,
-                       CLIm2ColFixture<uint8_t>,
+                       ClIm2ColFixture<uint8_t>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(13U, 11U, 11U, 2U)),
@@ -459,7 +419,7 @@ FIXTURE_DATA_TEST_CASE(Quantized,
  *  - im2col9x9_nhwc
  */
 FIXTURE_DATA_TEST_CASE(FP16,
-                       CLIm2ColFixture<half>,
+                       ClIm2ColFixture<half>,
                        framework::DatasetMode::ALL,
                        combine(combine(combine(combine(combine(combine(
                                                                    framework::dataset::make("InputShape", TensorShape(13U, 11U, 11U, 2U)),
