@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021, 2023 Arm Limited.
+ * Copyright (c) 2018-2021, 2023-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -34,6 +34,10 @@
 #include "tests/validation/Validation.h"
 #include "tests/validation/fixtures/ReduceMeanFixture.h"
 
+#include <algorithm>
+#include <cstdint>
+#include <vector>
+
 namespace arm_compute
 {
 namespace test
@@ -43,11 +47,19 @@ namespace validation
 namespace
 {
 constexpr AbsoluteTolerance<float> tolerance_f32(0.001f); /**< Tolerance value for comparing reference's output against implementation's output for 32-bit floating-point type */
-#ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
+#ifdef ARM_COMPUTE_ENABLE_FP16
 constexpr AbsoluteTolerance<float> tolerance_f16(0.03f); /**< Tolerance value for comparing reference's output against implementation's output for 16-bit floating-point type */
-#endif                                                   // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
+#endif                                                   // ARM_COMPUTE_ENABLE_FP16
+#ifdef __aarch64__
 constexpr AbsoluteTolerance<uint8_t> tolerance_u8(1);    /**< Tolerance value for comparing reference's output against implementation's output for unsigned 8-bit asymmetric quantized type */
+constexpr AbsoluteTolerance<int8_t>  tolerance_s8(1);    /**< Tolerance value for comparing reference's output against implementation's output for signed 8-bit asymmetric quantized type */
+#else // __aarch64__
+constexpr AbsoluteTolerance<uint8_t> tolerance_u8(2);    /**< Tolerance value for comparing reference's output against implementation's output for unsigned 8-bit asymmetric quantized type */
 constexpr AbsoluteTolerance<int8_t>  tolerance_s8(2);    /**< Tolerance value for comparing reference's output against implementation's output for signed 8-bit asymmetric quantized type */
+#endif // __aarch64__
+
+constexpr AbsoluteTolerance<uint8_t> zero_tolerance_u8(0);
+constexpr AbsoluteTolerance<int8_t>  zero_tolerance_s8(0);
 
 const auto axis_keep = combine(framework::dataset::make("Axis", { Coordinates(0), Coordinates(1, 0), Coordinates(1, 2), Coordinates(0, 2), Coordinates(1, 3), Coordinates(2, 3), Coordinates(0, 1, 2, 3) }),
                                framework::dataset::make("KeepDims", { true }));
@@ -56,6 +68,87 @@ const auto axis_drop = combine(framework::dataset::make("Axis", { Coordinates(0)
 TEST_SUITE(NEON)
 TEST_SUITE(ReduceMean)
 
+TEST_CASE(ProperRoundingPolicyXReduction, framework::DatasetMode::ALL)
+{
+    // We do not need to stress vector and leftover loops diffrently
+    // because the rounding is done scalarly at the end. Accumulation
+    // is done over integer types.
+    constexpr int x_len = 2;
+
+    const auto input_shape = TensorShape(x_len);
+    const auto output_shape = TensorShape(1);
+    const bool keep_dims = true;
+    const auto axis = Coordinates(0);
+    const auto input_qinfo = QuantizationInfo(2 / 255.f, 0);
+    const auto output_qinfo = QuantizationInfo(6 / 255.f, -1);
+    const auto dtype = DataType::QASYMM8_SIGNED;
+
+    Tensor input = create_tensor<Tensor>(input_shape, dtype, 1, input_qinfo);
+    Tensor output = create_tensor<Tensor>(output_shape, dtype, 1, output_qinfo);
+
+    NEReduceMean reduce_mean;
+    reduce_mean.configure(&input, axis, keep_dims, &output);
+
+    input.allocator()->allocate();
+    output.allocator()->allocate();
+
+    std::vector<int8_t> values {50, 26};
+    library->fill_static_values(Accessor(input), values);
+
+    std::vector<int8_t> expected {12};
+    SimpleTensor<int8_t> ref{ output_shape, dtype, 1, input_qinfo };
+    library->fill_static_values(ref, expected);
+
+    reduce_mean.run();
+
+    // The tolerance should be 0 because this test stresses the rounding behavior of the operator
+    validate(Accessor(output), ref, zero_tolerance_s8);
+}
+
+#ifdef __aarch64__
+// Due to the lack of instructions in a32, the rounding operation is less
+// accurate
+TEST_CASE(ProperRoundingPolicyNonXReduction, framework::DatasetMode::ALL)
+{
+    constexpr int x_len = 17; // > 16 to stress both vector and leftover loops
+
+    const auto input_shape = TensorShape(x_len, 2, 2, 1);
+    const auto output_shape = TensorShape(x_len, 1, 1, 1);
+    const bool keep_dims = true;
+    const auto axis = Coordinates(1, 2);
+    const auto input_qinfo = QuantizationInfo(2 / 255.f, 127);
+    const auto output_qinfo = QuantizationInfo(2 / 255.f, 127);
+    const auto dtype = DataType::QASYMM8;
+
+    Tensor input = create_tensor<Tensor>(input_shape, dtype, 1, input_qinfo);
+    Tensor output = create_tensor<Tensor>(output_shape, dtype, 1, output_qinfo);
+
+    NEReduceMean reduce_mean;
+    reduce_mean.configure(&input, axis, keep_dims, &output);
+
+    input.allocator()->allocate();
+    output.allocator()->allocate();
+
+    // {139, 139 ... 139 (x_len times) 154, 154, ... 154 (x_len_times) ...}
+    std::vector<uint8_t> values;
+    fill_n(back_inserter(values), x_len, 139);
+    fill_n(back_inserter(values), x_len, 154);
+    fill_n(back_inserter(values), x_len, 164);
+    fill_n(back_inserter(values), x_len, 179);
+    library->fill_static_values(Accessor(input), values);
+
+    std::vector<uint8_t> expected;
+    fill_n(back_inserter(expected), x_len, 159); // 159 = (139 + 154 + 164 + 179) / 4
+    SimpleTensor<uint8_t> ref{ output_shape, dtype, 1, input_qinfo };
+    library->fill_static_values(ref, expected);
+
+    reduce_mean.run();
+
+    // The tolerance should be 0 because this test stresses the rounding behavior of the operator
+    validate(Accessor(output), ref, zero_tolerance_u8);
+}
+#endif // __aarch64__
+
 // *INDENT-OFF*
 // clang-format off
 DATA_TEST_CASE(Validate, framework::DatasetMode::ALL, zip(zip(zip(zip(
@@ -88,15 +181,23 @@ using NEReduceMeanFixture = ReduceMeanFixture<Tensor, Accessor, NEReduceMean, T>
 
 TEST_SUITE(Float)
 
-#ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
+#ifdef ARM_COMPUTE_ENABLE_FP16
 TEST_SUITE(FP16)
 FIXTURE_DATA_TEST_CASE(RunSmall,
                        NEReduceMeanFixture<half>,
                        framework::DatasetMode::PRECOMMIT,
                        combine(combine(datasets::Small4DShapes(), framework::dataset::make("DataType", DataType::F16)), concat(axis_keep, axis_drop)))
 {
-    // Validate output
-    validate(Accessor(_target), _reference, tolerance_f16);
+    if(CPUInfo::get().has_fp16())
+    {
+        // Validate output
+        validate(Accessor(_target), _reference, tolerance_f16);
+    }
+    else
+    {
+        ARM_COMPUTE_TEST_INFO("Device does not support fp16 vector operations. Test SKIPPED.");
+        framework::ARM_COMPUTE_PRINT_INFO();
+    }
 }
 
 FIXTURE_DATA_TEST_CASE(RunLarge,
@@ -104,11 +205,19 @@ FIXTURE_DATA_TEST_CASE(RunLarge,
                        framework::DatasetMode::NIGHTLY,
                        combine(combine(datasets::Large4DShapes(), framework::dataset::make("DataType", DataType::F16)), concat(axis_keep, axis_drop)))
 {
-    // Validate output
-    validate(Accessor(_target), _reference, tolerance_f16);
+    if(CPUInfo::get().has_fp16())
+    {
+        // Validate output
+        validate(Accessor(_target), _reference, tolerance_f16);
+    }
+    else
+    {
+        ARM_COMPUTE_TEST_INFO("Device does not support fp16 vector operations. Test SKIPPED.");
+        framework::ARM_COMPUTE_PRINT_INFO();
+    }
 }
 TEST_SUITE_END() // FP16
-#endif           // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
+#endif           // ARM_COMPUTE_ENABLE_FP16
 TEST_SUITE(FP32)
 FIXTURE_DATA_TEST_CASE(RunSmall,
                        NEReduceMeanFixture<float>,
