@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Arm Limited.
+ * Copyright (c) 2018-2021, 2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -98,17 +98,25 @@ template <typename T>
 using NESplitShapesFixture = SplitShapesFixture<Tensor, ITensor, Accessor, NESplit, T>;
 
 TEST_SUITE(Float)
-#ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
+#ifdef ARM_COMPUTE_ENABLE_FP16
 TEST_SUITE(FP16)
 FIXTURE_DATA_TEST_CASE(RunSmall,
                        NESplitFixture<half>,
                        framework::DatasetMode::PRECOMMIT,
                        combine(datasets::SmallSplitDataset(), framework::dataset::make("DataType", DataType::F16)))
 {
-    // Validate outputs
-    for(unsigned int i = 0; i < _target.size(); ++i)
+    if(CPUInfo::get().has_fp16())
     {
-        validate(Accessor(_target[i]), _reference[i]);
+        // Validate outputs
+        for(unsigned int i = 0; i < _target.size(); ++i)
+        {
+            validate(Accessor(_target[i]), _reference[i]);
+        }
+    }
+    else
+    {
+        ARM_COMPUTE_TEST_INFO("Device does not support fp16 vector operations. Test SKIPPED.");
+        framework::ARM_COMPUTE_PRINT_INFO();
     }
 }
 
@@ -117,14 +125,22 @@ FIXTURE_DATA_TEST_CASE(RunLarge,
                        framework::DatasetMode::NIGHTLY,
                        combine(datasets::LargeSplitDataset(), framework::dataset::make("DataType", DataType::F16)))
 {
-    // Validate outputs
-    for(unsigned int i = 0; i < _target.size(); ++i)
+    if(CPUInfo::get().has_fp16())
     {
-        validate(Accessor(_target[i]), _reference[i]);
+        // Validate outputs
+        for(unsigned int i = 0; i < _target.size(); ++i)
+        {
+            validate(Accessor(_target[i]), _reference[i]);
+        }
+    }
+    else
+    {
+        ARM_COMPUTE_TEST_INFO("Device does not support fp16 vector operations. Test SKIPPED.");
+        framework::ARM_COMPUTE_PRINT_INFO();
     }
 }
 TEST_SUITE_END() // FP16
-#endif           /* __ARM_FEATURE_FP16_VECTOR_ARITHMETIC */
+#endif           /* ARM_COMPUTE_ENABLE_FP16 */
 
 TEST_SUITE(FP32)
 FIXTURE_DATA_TEST_CASE(RunSmall,
