@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2022-2023 Arm Limited.
+ * Copyright (c) 2022-2024 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -22,18 +22,17 @@
  * SOFTWARE.
  */
 
-#ifndef ACL_INTERNAL_TEST_CKW_IN_DF // Do not include this test if ACL_INTERNAL_TEST_CKW_IN_DF and the op has not been ported to ckw
 #include "arm_compute/dynamic_fusion/sketch/gpu/operators/GpuDepthwiseConv2d.h"
 
 #include "tests/CL/CLAccessor.h"
 #include "tests/datasets/DepthwiseConvolutionLayerDataset.h"
 #include "tests/datasets/DilatedDepthwiseConvolutionLayerDataset.h"
 #include "tests/framework/Asserts.h"
+#include "tests/framework/datasets/Datasets.h"
 #include "tests/framework/Fixture.h"
 #include "tests/framework/Macros.h"
-#include "tests/framework/datasets/Datasets.h"
-#include "tests/validation/Validation.h"
 #include "tests/validation/fixtures/dynamic_fusion/gpu/cl/DepthwiseConv2dFixture.h"
+#include "tests/validation/Validation.h"
 
 namespace arm_compute
 {
@@ -41,16 +40,18 @@ namespace test
 {
 namespace validation
 {
-const auto depth_multipliers       = framework::dataset::make("DepthMultiplier", { 1U, 4U });
-const auto large_depth_multipliers = framework::dataset::make("DepthMultiplier", { 1, 2, 5, 8 });
+const auto depth_multipliers       = framework::dataset::make("DepthMultiplier", {1U, 4U});
+const auto large_depth_multipliers = framework::dataset::make("DepthMultiplier", {1, 2, 5, 8});
 
 TEST_SUITE(CL)
 TEST_SUITE(DYNAMIC_FUSION)
 TEST_SUITE(DEPTHWISE_CONV2D)
 
-RelativeTolerance<float>            tolerance_f32(0.01f);                 /**< Tolerance value for comparing reference's output against implementation's output for DataType::F32 */
-RelativeTolerance<half_float::half> tolerance_f16(half_float::half(0.1)); /**< Tolerance value for comparing reference's output against implementation's output for DataType::F16 */
-constexpr float                     tolerance_num = 0.02f;                /**< Tolerance number */
+RelativeTolerance<float> tolerance_f32(
+    0.01f); /**< Tolerance value for comparing reference's output against implementation's output for DataType::F32 */
+RelativeTolerance<half_float::half> tolerance_f16(half_float::half(
+    0.1)); /**< Tolerance value for comparing reference's output against implementation's output for DataType::F16 */
+constexpr float                     tolerance_num = 0.02f; /**< Tolerance number */
 
 // *INDENT-OFF*
 // clang-format off
@@ -246,9 +247,9 @@ DATA_TEST_CASE(Validate, framework::DatasetMode::ALL, zip(zip(zip(zip(zip(zip(zi
     GpuWorkloadContext context = GpuWorkloadContext{ &cl_compile_ctx };
     GpuWorkloadSketch sketch{ &context };
 
-    const TensorInfo sketch_input_info   = context.create_tensor_info(input_info);
-    const TensorInfo sketch_weights_info = context.create_tensor_info(weights_info);
-    const TensorInfo sketch_biases_info  = context.create_tensor_info(biases_info);
+    const ITensorInfo* sketch_input_info   = context.create_tensor_info(input_info);
+    const ITensorInfo* sketch_weights_info = context.create_tensor_info(weights_info);
+    const ITensorInfo* sketch_biases_info  = context.create_tensor_info(biases_info);
 
     DepthwiseConv2dAttributes attributes {};
     attributes.pad(padding)
@@ -256,7 +257,7 @@ DATA_TEST_CASE(Validate, framework::DatasetMode::ALL, zip(zip(zip(zip(zip(zip(zi
               .dilation(dilation)
               .depth_multiplier(depth_multiplier);
 
-    const Status status = GpuDepthwiseConv2d::validate_op(sketch, &sketch_input_info, &sketch_weights_info, &sketch_biases_info, attributes);
+    const Status status = GpuDepthwiseConv2d::validate_op(sketch, sketch_input_info, sketch_weights_info, sketch_biases_info, attributes);
     const bool res = bool(status);
     ARM_COMPUTE_EXPECT(res == expected, framework::LogLevel::ERRORS);
 }
@@ -264,39 +265,50 @@ DATA_TEST_CASE(Validate, framework::DatasetMode::ALL, zip(zip(zip(zip(zip(zip(zi
 // *INDENT-ON*
 
 template <typename T>
-using DynamicFusionGpuDepthwiseConv2dFixture = DynamicFusionGpuDepthwiseConv2dValidationFixture<CLTensor, CLAccessor, GpuDepthwiseConv2d, T>;
+using DynamicFusionGpuDepthwiseConv2dFixture =
+    DynamicFusionGpuDepthwiseConv2dValidationFixture<CLTensor, CLAccessor, GpuDepthwiseConv2d, T>;
 
 TEST_SUITE(Float)
 TEST_SUITE(FP16)
 TEST_SUITE(W3x3)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::ALL,
-                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset3x3(),
-                                               depth_multipliers),
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset3x3(), depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F16)),
                                framework::dataset::make("DataLayout", DataLayout::NHWC)))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::NIGHTLY, combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset3x3(),
-                                                                                                                        large_depth_multipliers),
-                                                                                                                        framework::dataset::make("DataType", DataType::F16)),
-                                                                                                                        framework::dataset::make("DataLayout", DataLayout::NHWC)))
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::NIGHTLY,
+                       combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset3x3(),
+                                               large_depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F16)),
+                               framework::dataset::make("DataLayout", DataLayout::NHWC)))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16);
 }
+
 TEST_SUITE(Dilation)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::ALL, combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset3x3(),
-                                                                                                                    depth_multipliers),
-                                                                                                                    framework::dataset::make("DataType", DataType::F16)),
-                                                                                                                    framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset3x3(),
+                                               depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F16)),
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseDilatedConvolutionLayerDataset3x3(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F16)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16);
 }
@@ -304,34 +316,44 @@ TEST_SUITE_END() // Dilation
 TEST_SUITE_END() // W3x3
 
 TEST_SUITE(Generic)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::ALL, combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset(),
-                                                                                                                    depth_multipliers),
-                                                                                                                    framework::dataset::make("DataType", DataType::F16)),
-                                                                                                                    framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset(), depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F16)),
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16, tolerance_num);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::NIGHTLY, combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset(),
-                                                                                                                        large_depth_multipliers),
-                                                                                                                        framework::dataset::make("DataType", DataType::F16)),
-                                                                                                                        framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::NIGHTLY,
+                       combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset(),
+                                               large_depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F16)),
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16, tolerance_num);
 }
 
 TEST_SUITE(Dilation)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::ALL, combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset(),
-                                                                                                                    depth_multipliers),
-                                                                                                                    framework::dataset::make("DataType", DataType::F16)),
-                                                                                                                    framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset(),
+                                               depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F16)),
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16, tolerance_num);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<half>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<half>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseDilatedConvolutionLayerDataset(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F16)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f16, tolerance_num);
 }
@@ -341,15 +363,18 @@ TEST_SUITE_END() // FP16
 
 TEST_SUITE(FP32)
 TEST_SUITE(W3x3)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::ALL,
-                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset3x3(),
-                                               depth_multipliers),
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset3x3(), depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
                                framework::dataset::make("DataLayout", DataLayout::NHWC)))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset3x3(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
@@ -360,7 +385,9 @@ FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<float>,
 
 TEST_SUITE(Dilation)
 
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::ALL,
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::ALL,
                        combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset3x3(),
                                                depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
@@ -368,7 +395,9 @@ FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<float>,
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseDilatedConvolutionLayerDataset3x3(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
@@ -380,46 +409,56 @@ TEST_SUITE_END() // Dilation
 TEST_SUITE_END() // W3x3
 
 TEST_SUITE(Generic)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::ALL,
-                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset(),
-                                               depth_multipliers),
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseConvolutionLayerDataset(), depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
 
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseConvolutionLayerDataset(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
 
-FIXTURE_DATA_TEST_CASE(RunLargeKernelSize, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::ALL,
+FIXTURE_DATA_TEST_CASE(RunLargeKernelSize,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::ALL,
                        combine(combine(combine(datasets::LargeKernelSizeDepthwiseConvolutionLayerNHWCDataset(),
-                                               framework::dataset::make("DepthMultiplier", { 1 })),
+                                               framework::dataset::make("DepthMultiplier", {1})),
                                        framework::dataset::make("DataType", DataType::F32)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
 
 TEST_SUITE(Dilation)
-FIXTURE_DATA_TEST_CASE(RunSmall, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::ALL, combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset(),
-                                                                                                                     depth_multipliers),
-                                                                                                                     framework::dataset::make("DataType", DataType::F32)),
-                                                                                                                     framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+FIXTURE_DATA_TEST_CASE(RunSmall,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::ALL,
+                       combine(combine(combine(datasets::SmallDepthwiseDilatedConvolutionLayerDataset(),
+                                               depth_multipliers),
+                                       framework::dataset::make("DataType", DataType::F32)),
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
-FIXTURE_DATA_TEST_CASE(RunLarge, DynamicFusionGpuDepthwiseConv2dFixture<float>, framework::DatasetMode::NIGHTLY,
+FIXTURE_DATA_TEST_CASE(RunLarge,
+                       DynamicFusionGpuDepthwiseConv2dFixture<float>,
+                       framework::DatasetMode::NIGHTLY,
                        combine(combine(combine(datasets::LargeDepthwiseDilatedConvolutionLayerDataset3x3(),
                                                large_depth_multipliers),
                                        framework::dataset::make("DataType", DataType::F32)),
-                               framework::dataset::make("DataLayout", { DataLayout::NHWC })))
+                               framework::dataset::make("DataLayout", {DataLayout::NHWC})))
 {
     validate(CLAccessor(_target), _reference, tolerance_f32);
 }
@@ -433,5 +472,3 @@ TEST_SUITE_END() // CL
 } // namespace validation
 } // namespace test
 } // namespace arm_compute
-
-#endif // ACL_INTERNAL_TEST_CKW_IN_DF
